/*******************************************************************************
*
* File:         Mi12Lite.c
* Description:  系统测试文件
* Version:      V0.1
* Date:         2020-02-22
* Author:       Tempest
 *******************************************************************************/
#include "Honor90Pro_demo.h"
#include "ArmCM0.h"
#include "tau_device_datatype.h"
#include "tau_log.h"
#include "tau_operations.h"
#include "tau_common.h"
#include "tau_delay.h"
#include "hal_dsi_rx_ctrl.h"
#include "hal_dsi_tx_ctrl.h"
#include "hal_swire.h"
#include "hal_timer.h"
#include "hal_system.h"
#include "hal_gpio.h"
#include "test_cfg_global.h"
#include "hal_pwr.h"
#include "hal_pwm.h"


#ifdef LOG_TAG
#undef LOG_TAG
#endif
#define LOG_TAG "Honor90Pro"

#if _DEMO_HONOR_90Pro_EN

/******************** FEATURE开关 ********************/
#define TOUCH_ENABLE                   false    /* Touch转换开关 */
#define RX_START_WITHOUT_RST           false    /* 不等待AP RESET直接启动RX,仅作为调试使用 */
#define RX_WAIT_TEAR_ON                false     /* 等待AP_TEAR_ON */
#define RX_RESOLUTION_CHANGE_ENABLE    true     /* 支持分辨率切换开关, AP存在分辨率切换时需要打开 */
#define RX_READ_HW_ACK                 true    /* AP DCS读命令使用硬件回复 */
#define TX_START_AFTER_APRST           false    /* 等待AP_reset 后做Panel初始化, 用于热拔插电源不稳定导致初始化失败 */
#define TX_USE_CMD_MODE                false    /* command mode输出开关 配置为True时需要把TD TE与 AP TE 接一起*/
#define TX_CMD_MODE_WITHOUT_TE         false    /* 屏端TE直接输出给AP,Scaler不看TE信号,AP每输入一帧输出一帧(C2C 60Hz->60Hz) */
#define AP_SWIRE_OUTPUT                true     /* swire信号输出,OLED项目配置 */
#define ANALOG_PWM_OUTPUT              false     /* 模拟PWM 调光开关 */
#define SHARE_FLASH_ENABLE             false    /* 共享flash开关 */

/*****************************************************/

/******************** 输出屏幕选择 ********************/
#define AMOLED_ICNA3520                1                   /* 4lane FHD Panel */
/*****************************************************/

#define TOUCH_PHONE_DIS_OFF_PIN            IO_PIN_6        // 通话熄屏响应管脚

/****************** 系统相关参数配置 ******************/
#define MAIN_POWER_SELECT              PWR_SEL_VCC           /* 主供电电源选择 */
#define SLEEP_MODE_POWER               PWR_SLEEP_IN_TP18     /* 息屏电源选择 */
#define SLEEP_MODE_SELECT              PWR_DEEP_SLEEP_MODE   /* sleep mode 配置 */
#define SWIRE_DEFAULT_PULSE            37                  /* SWIRE 波形配置 */
#define PWM_FREQUENCY                  30000                 /* PWM输出频率30Khz */
#define PWM_DUTY_STEP                  255                   /* PWM调光阶数255阶 */
/*****************************************************/

/********************RX 基本参数配置*******************/
//AP MIPI数据信息
/* 输入分辨率 */
#define INPUT_WIDTH  1224
#define INPUT_HEIGHT 2700
/* 输入 MIPI lane rate,需要正确配置,可50M step调整 */
#define INPUT_MIPI_LANE_RATE 1200000000
/* 输入图像格式 */
#define INPUT_COLOR_MODE DSI_RGB10_10_10
/* 输出数据格式(DSI_DATA_CMD_MODE , DSI_DATA_VIDEO_MODE) */
#define INPUT_DATA_MODE DSI_DATA_CMD_MODE
/* 输入mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define INPUT_MIPI_LANE_NUM DSI_LANE_4
/* 输入为video mode 时数据格式 */
#define INPUT_VIDEO_MODEL DSI_NONBURST_EVENT
/* 输入虚拟通道(0-3) */
#define INPUT_VC DSI_VC_0
/* 输入的帧率(60/90/120/144Hz) */
#define INPUT_FRAME_RATE DSI_FRAME_RATE_60HZ
/* 输入数据是否DSC压缩 */
#define INPUT_COMPRESS true
/*****************************************************/

/********************TX 基本参数配置*******************/
#if AMOLED_ICNA3520
/* 输出分辨率配置 */
#define OUTPUT_WIDTH 1224
#define OUTPUT_HEIGHT 2700
/* 输出虚拟通道(0-3) */
#define OUTPUT_VC DSI_VC_0
/* 输出mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define OUTPUT_LANE_NUMBER DSI_LANE_4
/* 输出数据格式(DSI_DATA_CMD_MODE , DSI_DATA_VIDEO_MODE) */
#if TX_USE_CMD_MODE
#define OUTPUT_DATA_MODE DSI_DATA_CMD_MODE
#else
#define OUTPUT_DATA_MODE DSI_DATA_VIDEO_MODE
#endif
/* 输出为video mode时的数据格式 */
#define OUTPUT_VIDEO_MODEL DSI_BURST_MODE
/* 输出 VSA */
#define OUTPUT_VSA  1//2
/* 输出 VBP */
#define OUTPUT_VBP  8//24 //20
/* 输出 VBP */
#define OUTPUT_VFP  24 // 14
/* 输出 VSA */
#define OUTPUT_HSA  2 //8
/* 输出 HBP */
#define OUTPUT_HBP  20  //31  
/* 输出 HFP */
#define OUTPUT_HFP  30  //200 
/* 初始化模式命令传输类型 LP/HS */
#define TX_INIT_TYPE            DSI_CMD_TX_LP
#endif
/******************************************************/

#if TOUCH_ENABLE
#include "app_tp_transfer.h"
#endif

/* 全局handle */
static hal_dsi_rx_ctrl_handle_t *g_rx_ctrl_handle = NULL;
static hal_dsi_tx_ctrl_handle_t *g_tx_ctrl_handle = NULL;

/* 屏初始化完成标志位 */
static bool panel_display_done = false;
static bool sg_system_resume = false;
static bool sg_system_suspend = false;
static bool sg_exit_idle_mode_flag = false;
static bool AOD_ON = false;
static bool rame_update_120HZ = false;

uint8_t phone_start_flag = 0;


static uint32_t src_bl;


static bool AOD_51_ON=false;
static bool panel_init_ready = true;

#if RX_WAIT_TEAR_ON
static bool sg_ap_set_tear_on = false;
#endif
#if TX_START_AFTER_APRST
static bool sg_tx_start_in_process = false;
#endif

void Gpio_swire_output(uint8_t flag, uint8_t num);

/* AP reset 回调函数声明 */
static void ap_rstn_pull_high_cb(void *data);
static void ap_rstn_pull_down_cb(void *data);
static void app_mipi_rx_start_cb(void *data);

bool note10_pro = false;

/*************************DCS 命令处理函数 BEGIN*************************/
#if RX_READ_HW_ACK
/**
* @brief  配置AP硬件回读
* @param  none
* @retval none
*/
static void app_set_dcs_hw_ack()
{
    hal_dsi_rx_ctrl_set_auto_ack(g_rx_ctrl_handle, HAL_RX_QRESP_CODE0, DSI_ACK_DT_DCS_SHORT_RESPONSE_1B, 0xBE, 1, 0x00);
		hal_dsi_rx_ctrl_set_auto_ack(g_rx_ctrl_handle, HAL_RX_QRESP_CODE1, DSI_ACK_DT_DCS_SHORT_RESPONSE_1B, 0xFA, 1, 0x01);
		hal_dsi_rx_ctrl_set_auto_ack(g_rx_ctrl_handle, HAL_RX_QRESP_CODE2, DSI_ACK_DT_DCS_SHORT_RESPONSE_1B, 0x0A, 1, 0x9C);
}
#endif
/**
* @brief  ap 读回调函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static uint8_t b3_read_flag = 0;
static uint8_t c8_read_flag = 0;
static uint8_t c9_read_flag = 0;

static bool ap_dcs_read(uint8_t data_type, uint8_t dcs_cmd, uint8_t param)
{
    uint32_t data_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
    if(dcs_cmd == 0xBE)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x00);
    }
		else if (dcs_cmd == 0x00)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0x32);
    }
    else if(dcs_cmd == 0x01)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_GEN_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x33);
    }
    else   if(dcs_cmd == 0x02)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_GEN_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x30);
    }
    else   if(dcs_cmd == 0x03)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x32);
    }
		else   if(dcs_cmd == 0x04 || dcs_cmd == 0x05)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x41);
    }
		else   if(dcs_cmd == 0x06)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x44);
    }
		else   if(dcs_cmd == 0x07)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x43);
    }
		else   if(dcs_cmd == 0x08)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x56);
    }
		else   if(dcs_cmd == 0x09)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x30);
    }
		else   if(dcs_cmd == 0x0A)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x9C);
    }
		else   if(dcs_cmd == 0x0B)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x34);
    }
		else   if(dcs_cmd == 0x0C)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x33);
    }
		else   if(dcs_cmd == 0x0D)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x34);
    }
		else   if(dcs_cmd == 0x0E)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x42);
    }
		else   if(dcs_cmd == 0x0F)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x32);
    }
		else   if(dcs_cmd == 0x10)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x37);
    }
		else   if(dcs_cmd == 0x11)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x43);
    }
		else   if(dcs_cmd == 0x12)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x45);
    }
		else   if(dcs_cmd == 0x13)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x31);
    }
		else   if(dcs_cmd == 0x14)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x44);
    }

		else   if(dcs_cmd == 0xFA)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1,
                                     0x01);
    }
//		else
		{
  	   TAU_LOGD("dcs_cmd %X %d\n",dcs_cmd , data_size);			
		}




    return true;
}

#if RX_RESOLUTION_CHANGE_ENABLE
/* PPS update callback 用于分辨率切换case */
static bool pps_update_handle(uint8_t *pps, uint8_t size, uint32_t pic_width, uint32_t pic_height)
{
    /* AVDD 上电, 用于解决息屏开屏PPS不更新问题 */
    hal_gpio_set_output_data(IO_PAD_AP_PWMEN, IO_LVL_HIGH);
    if (pic_width != g_rx_ctrl_handle->base_info.src_w || pic_height != g_rx_ctrl_handle->base_info.src_h)
    {
   //     hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_USER_MODE);
        /* PPS Update 且分辨率发生变化 */
        g_rx_ctrl_handle->base_info.src_w = pic_width;
        g_rx_ctrl_handle->base_info.src_h = pic_height;
        /* 注意部分基板更新PPS前不发 Compression Mode Command的情况 */
        g_rx_ctrl_handle->compress_en = true; //hal_dsi_rx_ctrl_get_compressen_en(g_rx_ctrl_handle);
        g_tx_ctrl_handle->base_info.src_w = pic_width;
        g_tx_ctrl_handle->base_info.src_h = pic_height;

        hal_dsi_rx_ctrl_toggle_resolution(g_rx_ctrl_handle);
        TAU_LOGD("resolution update w[%d] h[%d] compress[%d]\n", pic_width, pic_height, g_rx_ctrl_handle->compress_en);
  //      hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
    }
 //   TAU_LOGD("PPS Update[%d][%d] [%d][%d]\n", pic_width, pic_height, g_rx_ctrl_handle->base_info.src_w, g_rx_ctrl_handle->base_info.src_h);
    return true;
}
#endif


static uint8_t display_on_flag =0;  
/**
* @brief  ap display on处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_display_on(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
	AOD_ON = true;
	 display_on_flag =1;  
    TAU_LOGD("disp on \n");
    return true;
}

/**
* @brief  ap display off处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_display_off(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    TAU_LOGD("disp off %d\n", panel_display_done);
//    if (panel_display_done)
//    {
//        hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x28);

//    }
#if ANALOG_PWM_OUTPUT
    hal_pwm_enable(false);
#endif
    return true;
}

/**
* @brief  ap enter sleep mode处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_enter_sleep_mode(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
 //   TAU_LOGD("enter sleep mode \n", panel_display_done);
    if (panel_display_done)
    {
		hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_STOP_MODE);
   //     hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x10);
	delayMs(10);
    }

#if AP_SWIRE_OUTPUT
    /* Swire close */
    hal_swire_enable(false);
		delayMs(10);
	hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x10);
	 delayMs(20);  //20
    /* AVDD_EN close*/
    hal_gpio_set_output_data(IO_PAD_AP_PWMEN, IO_LVL_LOW);
#endif
	    delayMs(20);  //20
	hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_LOW);

    /* Wait AP reset down*/
    hal_gpio_set_ap_reset_int(ENABLE, ap_rstn_pull_down_cb, DETECT_LOW_LVL);
    return true;
}

/**
* @brief  ap exit sleep mode处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_exit_sleep_mode(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
#if AP_SWIRE_OUTPUT
    /* AVDD 上电, 用于解决息屏开屏PPS不更新问题 */
 //   hal_gpio_set_output_data(IO_PAD_AP_PWMEN, IO_LVL_HIGH);
#endif

#if TX_START_AFTER_APRST
    if (panel_display_done == false)
    {
        sg_tx_start_in_process = true;
    }
#endif

    TAU_LOGD("exit sleep mode \n");

    return true;
}

/* 调整背光B1回调      g_cus_rx_dcs_execute_table 里配置为异步执行，CA同理*/

static uint8_t bl_adj_flag =0;   
uint16_t value_reg_b1 =0;
uint32_t value_reg_ca =0;
//static uint32_t value_reg_b5 =0;
static uint32_t value_reg_df =0;
static uint8_t value_blue =0;
static uint8_t blue_flag =0;
#if 1 //护眼设置
#define BLUE_MAX			0xF0	//蓝光最大值
#define BLUE_MIN			0x86	//蓝光最小值
#define BLUE_STEP			10		//蓝光等级数-1
#endif

/**
* @brief  护眼模式回调函数
* @param  rx_ctrl_handle: dsi rx handle;
*         dcs packet: dcs_packet
* @retval true/false
*/
static bool ap_dcs_set_exit_idle_mode(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    sg_exit_idle_mode_flag = true;
    hal_dsi_rx_ctrl_set_hw_cmd_filter(g_rx_ctrl_handle, HAL_RX_DCS_FILTER_B, 0x2C, 0x2C);
    TAU_LOGD("exit idle mode,skip 0x2C\n");
    return true;
}

/**
* @brief  帧率切换处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/


 static bool ap_update_frame_rate(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
		TAU_LOGD("60: %04x %d\n", dcs_packet->packet_param[0],dcs_packet->param_length);
	
		if (dcs_packet->param_length == 1)
    {
        if (dcs_packet->packet_param[0] == 0x01)
        {
     //       hal_dsi_rx_ctrl_toggle_input_frame_rate(g_rx_ctrl_handle, DSI_FRAME_RATE_120HZ);
						hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle,  TE_60HZ_MODE);
            TAU_LOGD("updata frame 120Hz\n");
        }
        else //if (dcs_packet->packet_param[0] == 0x21)
        {
   //         hal_dsi_rx_ctrl_toggle_input_frame_rate(g_rx_ctrl_handle, DSI_FRAME_RATE_60HZ);
						hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle,  TE_60HZ_MODE);
            TAU_LOGD("updata frame 60Hz\n");
        }

    }
    return true;
}

#if 1
uint8_t s_pps[128] = {
	
	          0x11,0x00,0x00,0x89,0x30,0x80,0x09,0x60,
            0x04,0x38,0x00,0x14,0x02,0x1C,0x02,0x1C,
            0x02,0x00,0x02,0x0E,0x00,0x20,0x01,0xE8,
            0x00,0x07,0x00,0x0C,0x05,0x0E,0x05,0x16,
            0x18,0x00,0x10,0xF0,0x03,0x0C,0x20,0x00,
            0x06,0x0B,0x0B,0x33,0x0E,0x1C,0x2A,0x38,
            0x46,0x54,0x62,0x69,0x70,0x77,0x79,0x7B,
            0x7D,0x7E,0x01,0x02,0x01,0x00,0x09,0x40,
            0x09,0xBE,0x19,0xFC,0x19,0xFA,0x19,0xF8,
            0x1A,0x38,0x1A,0x78,0x1A,0xB6,0x2A,0xF6,
            0x2B,0x34,0x2B,0x74,0x3B,0x74,0x6B,0xF4,
            0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
            0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
            0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
            0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
            0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
				   };

static bool ap_update_pps_9E(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    uint32_t pic_width, pic_height;
#if 1

	pic_height = (dcs_packet->packet_param[6]<<8) + dcs_packet->packet_param[7];
	pic_width = (dcs_packet->packet_param[8]<<8) + dcs_packet->packet_param[9];
//	
	TAU_LOGD("resolution update w[%d] h[%d] compress[%d], len[%d]!!\n", pic_width, pic_height, g_rx_ctrl_handle->compress_en ,dcs_packet->param_length);
//	if (pic_width != g_rx_ctrl_handle->base_info.src_w || pic_height != g_rx_ctrl_handle->base_info.src_h)	
	{
		for (int i = 0; i < dcs_packet->param_length; i++)
	    {
	        s_pps[i] = dcs_packet->packet_param[i];
//				  TAU_LOGD("%x",s_pps[i]);
	    }
		hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, s_pps, 128);
		hal_dsi_rx_ctrl_toggle_resolution(g_rx_ctrl_handle);
	}
    return true;
#endif	
}

#endif

/**
* @brief  ap_set_backlight on处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_set_backlight(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    uint16_t ap_backlight = dcs_packet->packet_param[1] + (dcs_packet->packet_param[0] << 8);
//    TAU_LOGD("51: %04x\n", ap_backlight);
	
		if(ap_backlight < 0x500)   ap_backlight = 0x600;
	
		hal_dsi_tx_ctrl_write_cmd(0x29, 0, 3, 0x51, ap_backlight >> 8, ap_backlight & 0xFF);
		
		return true;
}

#if RX_WAIT_TEAR_ON
/**
* @brief  ap set tear on 处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_tear_on(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    TAU_LOGD("ap_set_tear_on\n");
    sg_ap_set_tear_on = true;
    if(panel_display_done == false)
    {
        TAU_LOGD("gen a tear\n");
        hal_dsi_tx_ctrl_gen_a_tear_signal();
    }
    else
    {
        hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
    }
    return true;
}

/**
* @brief  ap set tear off 处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_tear_off(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    TAU_LOGD("ap_set_tear_off \n");
    sg_ap_set_tear_on = false;
    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_USER_MODE);
    return true;
}
#endif

/*************************DCS 命令处理函数 END*************************/

/* 客制化DCS command 处理函数表格 */
static const hal_dcs_execute_entry_t g_cus_rx_dcs_execute_table[] =
{
    {DCS_SET_DISPLAY_ON, ap_dcs_set_display_on, false},
    {DCS_SET_DISPLAY_OFF, ap_dcs_set_display_off, true},
//		{0xDF, ap_get_reg_df, false},  //蓝光
//		{0xCA, ap_get_reg_ca, false},  // 背光。要加上B1才能调流畅
//		{0xB1, ap_set_backlight, false},
//  {0x53, ap_set_aod, false},
//		{0x9E, ap_update_pps_9E, true},
		{0x60, ap_update_frame_rate,        true},  	
    {0x51, ap_set_backlight,            false },
    {DCS_ENTER_SLEEP_MODE, ap_dcs_set_enter_sleep_mode, true},
    {DCS_EXIT_SLEEP_MODE, ap_dcs_set_exit_sleep_mode, true},
    //{0x2F, ap_dcs_set_frame_change, true},

#if RX_WAIT_TEAR_ON
    {DCS_SET_TEAR_ON, ap_dcs_set_tear_on, true},
    {DCS_SET_TEAR_OFF, ap_dcs_set_tear_off, true},
#endif
 //   {0x38, ap_dcs_set_exit_idle_mode, true},
    {0, NULL, false}                        //{0,NULL,false} 数组最后一个固定成员，作为table结尾的判断标准
};

/**
* @brief  panel reset
* @param  none
* @retval none
*/
static void app_tx_panel_reset(void)
{
#if SHARE_FLASH_ENABLE
    hal_flash_share_mode(true);
#endif
    hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_HIGH);
    delayMs(10);
    hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_LOW);
    delayMs(10);
    hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_HIGH);
    delayMs(40);
}

#define PANEL_INIT_CODE_ARRAY		 1
#if PANEL_INIT_CODE_ARRAY
static void send_panel_init_code(uint32_t size, uint8_t * data)
{
	uint32_t data_offeset = 0;
	uint8_t data_type;
	uint8_t vc;
	uint8_t data_size;
	uint8_t * p_data;

	while(data_offeset < size)
	{
		data_type = data[data_offeset];
		vc = data[data_offeset + 1];
		data_size = data[data_offeset + 2];
		p_data = &data[data_offeset + 3];
		hal_dsi_tx_ctrl_write_array_cmd(data_type, vc, data_size, p_data);
		data_offeset = data_offeset + data_size + 3;
    delayUs(100);
	}
}

const uint8_t panel_init_code[] = {

#if AMOLED_ICNA3520
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x00,
0x39,0,2,0x6F,0x01,
0x39,0,3,0xB9,0x04,0xC8,
0x39,0,3,0xBD,0x0A,0x8C,
0x39,0,8,0xBA,0x00,0x5E,0x00,0x10,0x0A,0xD4,0x10,
0x39,0,2,0x6F,0x07,
0x39,0,8,0xBA,0x00,0x5E,0x00,0x10,0x00,0x24,0x10,
0x39,0,2,0x6F,0x0E,
0x39,0,8,0xBA,0x00,0x5E,0x00,0x10,0x03,0xBC,0x10,
0x39,0,8,0xBB,0x00,0x5E,0x00,0x10,0x00,0x24,0x70,
0x39,0,4,0xBE,0x47,0x4A,0x46,
0x39,0,11,0xC1,0x00,0x5E,0x00,0x5E,0x00,0x5E,0x00,0x5E,0x00,0x5E,
0x39,0,17,0xC6,0x44,0x44,0x44,0x44,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,
0x39,0,2,0xC8,0x6E,
0x39,0,2,0x6F,0x2C,
0x39,0,2,0xCB,0x43,
0x39,0,3,0xB2,0x01,0x40,
0x39,0,2,0x6F,0x04,
0x39,0,2,0xB2,0x22,
0x39,0,2,0x6F,0x05,
0x39,0,3,0xB2,0x40,0x40,
0x39,0,2,0x6F,0x11,
0x39,0,4,0xB2,0x1F,0x0F,0x17,
0x39,0,2,0x6F,0x15,
0x39,0,2,0xB2,0x03,
0x39,0,2,0x6F,0x18,
0x39,0,5,0xB2,0x14,0x20,0x0F,0xFF,
0x39,0,31,0xB3,0x00,0x01,0x00,0xDA,0x00,0xDA,0x01,0x6C,0x01,0x6C,0x02,0x2D,0x02,0x2D,0x03,0x70,0x03,0x70,0x05,0x08,0x05,0x08,0x05,0x09,0x05,0x09,0x05,0x0A,0x05,0x0A,
0x39,0,2,0x6F,0x1E,
0x39,0,15,0xB3,0x06,0x96,0x06,0x96,0x0A,0xC9,0x0A,0xC9,0x0D,0xBB,0x0D,0xBB,0x0F,0xFF,
0x39,0,2,0x6F,0x2C,
0x39,0,9,0xB3,0x01,0x55,0x07,0xFF,0x07,0xFF,0x0F,0xFF,
0x39,0,31,0xB4,0x15,0x70,0x14,0x20,0x13,0x80,0x13,0x80,0x12,0x80,0x12,0x80,0x10,0x80,0x10,0x80,0x0B,0x60,0x0B,0x60,0x02,0x40,0x02,0x40,0x00,0x20,0x00,0x20,0x00,0x20,
0x39,0,2,0x6F,0x1E,
0x39,0,17,0xB4,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,0x00,0x20,
0x39,0,2,0x6F,0x2E,
0x39,0,31,0xB4,0x0A,0xC0,0x0A,0x10,0x09,0xC0,0x09,0xC0,0x09,0x40,0x09,0x40,0x08,0x30,0x08,0x30,0x05,0xA0,0x05,0xA0,0x01,0x00,0x01,0x00,0x00,0x10,0x00,0x10,0x00,0x10,
0x39,0,2,0x6F,0x4C,
0x39,0,17,0xB4,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,
0x39,0,2,0x6F,0x5C,
0x39,0,31,0xB4,0x0E,0x58,0x0D,0x68,0x0D,0x08,0x0D,0x08,0x0C,0x60,0x0C,0x60,0x0A,0xF8,0x0A,0xF8,0x07,0x98,0x07,0x98,0x01,0x80,0x01,0x80,0x00,0x18,0x00,0x18,0x00,0x18,
0x39,0,2,0x6F,0x4C,
0x39,0,17,0xB4,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,0x00,0x18,
0x39,0,2,0x6F,0xB8,
0x39,0,11,0xB4,0x0A,0xC0,0x00,0x40,0x00,0x40,0x00,0x40,0x00,0x40,
0x39,0,2,0xC0,0x04,
0x39,0,2,0x6F,0x02,
0x39,0,2,0xC0,0x08,
0x39,0,2,0x6F,0x03,
0x39,0,3,0xC0,0x21,0x22,
0x39,0,2,0x6F,0x05,
0x39,0,3,0xC0,0x33,0x33,
0x39,0,2,0x6F,0x0B,
0x39,0,11,0xC0,0xE4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0xB5,0x86,
0x39,0,2,0x6F,0x06,
0x39,0,2,0xB5,0x7F,
0x39,0,2,0x6F,0x07,
0x39,0,4,0xB5,0x4B,0x21,0x4F,
0x39,0,2,0x6F,0x0C,
0x39,0,4,0xB5,0x4B,0x29,0x00,
0x39,0,2,0x6F,0x11,
0x39,0,6,0xB5,0x21,0x21,0x21,0x21,0x21,
0x39,0,2,0x6F,0x02,
0x39,0,14,0xB6,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,0x2E,
0x39,0,27,0xB7,0x13,0x12,0x11,0x10,0x0F,0x0E,0x0D,0x0C,0x0B,0x0A,0x09,0x08,0x07,0x06,0x05,0x04,0x03,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x19,
0x39,0,13,0xB7,0xAB,0xBC,0xDD,0xEE,0xEE,0xEE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x39,0,2,0x6F,0x25,
0x39,0,25,0xB7,0xC9,0x60,0xF6,0x8D,0x24,0xBB,0xE4,0x0D,0x37,0x60,0x8A,0xB3,0xDC,0x06,0x2F,0x59,0x82,0xAC,0xD5,0xFF,0xFF,0xFF,0xFF,0xFF,
0x39,0,2,0x6F,0x0C,
0x39,0,2,0xC3,0x00,
0x39,0,2,0x6F,0x07,
0x39,0,3,0xCA,0x09,0x06,
0x39,0,2,0x6F,0x09,
0x39,0,3,0xCA,0x36,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x01,
0x39,0,3,0xB0,0x32,0x32,
0x39,0,3,0xB1,0x32,0x32,
0x39,0,5,0xB2,0x55,0x01,0x55,0x01,
0x39,0,7,0xB3,0x44,0x44,0x44,0x44,0x44,0x44,
0x39,0,2,0x6F,0x08,
0x39,0,5,0xB4,0x00,0x00,0x00,0x00,
0x39,0,9,0xB5,0x01,0x04,0x01,0x04,0x00,0xF0,0x00,0xF0,
0x39,0,2,0x6F,0x08,
0x39,0,9,0xB5,0x01,0x04,0x01,0x04,0x00,0xF0,0x00,0xF0,
0x39,0,9,0xB6,0x00,0x96,0x00,0xD2,0x01,0x36,0x00,0xFA,
0x39,0,8,0xB7,0x27,0x27,0x27,0x27,0x27,0x27,0x27,
0x39,0,2,0x6F,0x11,
0x39,0,2,0xB7,0x27,
0x39,0,2,0x6F,0x13,
0x39,0,2,0xB7,0x27,
0x39,0,8,0xB8,0x50,0x50,0x50,0x50,0x50,0x50,0x50,
0x39,0,2,0x6F,0x0E,
0x39,0,2,0xB8,0x50,
0x39,0,2,0x6F,0x10,
0x39,0,2,0xB8,0x50,
0x39,0,2,0x6F,0x07,
0x39,0,8,0xB9,0x23,0x23,0x23,0x23,0x23,0x23,0x23,
0x39,0,2,0x6F,0x1C,
0x39,0,2,0xB9,0x23,
0x39,0,2,0x6F,0x20,
0x39,0,2,0xB9,0x23,
0x39,0,2,0xBB,0x33,
0x39,0,2,0x6F,0x05,
0x39,0,24,0xBB,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x4A,
0x39,0,2,0x6F,0x1C,
0x39,0,24,0xBB,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x34,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x47,
0x39,0,7,0xDE,0x10,0x00,0x10,0x00,0x00,0x00,
0x39,0,27,0xE0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0x00,0x11,0x00,0x11,0x00,0x11,0x00,0x11,0x00,0x00,
0x39,0,27,0xE0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,4,0xBA,0x15,0x15,0x10,
0x39,0,2,0xCC,0x00,
0x39,0,2,0xCD,0x71,
0x39,0,2,0x6F,0x12,
0x39,0,4,0xD8,0x40,0x50,0x30,
0x39,0,2,0x6F,0x18,
0x39,0,2,0xD8,0x20,
0x39,0,2,0x6F,0x1D,
0x39,0,2,0xD8,0x20,
0x39,0,2,0x6F,0x1E,
0x39,0,2,0xD8,0x30,
0x39,0,2,0x6F,0x21,
0x39,0,4,0xD8,0x60,0x60,0x60,
0x39,0,2,0x6F,0x24,
0x39,0,3,0xD8,0x50,0x50,
0x39,0,2,0x6F,0x0F,
0x39,0,2,0xB7,0xA0,
0x39,0,2,0x6F,0x07,
0x39,0,2,0xE3,0x28,
0x39,0,2,0x6F,0x02,
0x39,0,2,0xE9,0x00,
0x39,0,3,0xD2,0x00,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xBC,0x11,
0x39,0,17,0xBD,0x96,0x00,0x69,0x00,0x00,0x96,0x00,0x69,0xBB,0x44,0x44,0xBB,0xEE,0x11,0x11,0xEE,
0x39,0,2,0xC1,0x02,
0x39,0,5,0xC2,0x91,0x00,0x19,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x03,
0x39,0,3,0xCA,0x06,0x06,
0x39,0,2,0xB2,0x00,
0x39,0,2,0x6F,0x01,
0x39,0,8,0xB2,0x00,0x11,0x11,0x00,0x06,0x00,0x01,
0x39,0,2,0x6F,0x08,
0x39,0,10,0xB2,0x00,0x11,0x11,0x00,0x11,0x11,0x00,0x11,0x11,
0x39,0,2,0x6F,0x14,
0x39,0,13,0xB2,0x00,0x06,0x00,0x01,0x00,0x06,0x00,0x01,0x00,0x06,0x00,0x01,
0x39,0,2,0x6F,0x11,
0x39,0,4,0xB2,0x00,0x11,0x11,
0x39,0,2,0x6F,0x20,
0x39,0,5,0xB2,0x00,0x06,0x00,0x01,
0x39,0,16,0xB4,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,
0x39,0,14,0xB6,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x0D,
0x39,0,4,0xB6,0x00,0x00,0x00,
0x39,0,2,0x6F,0x10,
0x39,0,10,0xB6,0x1F,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x19,
0x39,0,28,0xB6,0x0F,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x34,
0x39,0,10,0xB6,0x0F,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,15,0xBB,0x11,0x00,0x00,0x18,0x5B,0x00,0x18,0x5B,0x00,0x18,0x5B,0x00,0x18,0x5B,
0x39,0,2,0x6F,0x0E,
0x39,0,4,0xBB,0x00,0x18,0x5B,
0x39,0,15,0xBC,0x22,0x10,0x00,0x00,0x20,0x00,0x00,0x20,0x00,0x00,0x20,0x00,0x00,0x20,
0x39,0,2,0x6F,0x0E,
0x39,0,4,0xBC,0x00,0x00,0x20,
0x39,0,2,0xC7,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x00,
0x39,0,2,0x6F,0x01,
0x39,0,2,0xC0,0x20,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x00,
0x39,0,2,0x6F,0x2E,
0x39,0,2,0xC0,0x12,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x04,
0x39,0,2,0xB5,0x08,
0x39,0,2,0x6F,0x01,
0x39,0,4,0xB5,0x00,0x04,0x3F,
0x39,0,2,0x6F,0x04,
0x39,0,2,0xB5,0xE4,
0x39,0,2,0x6F,0x0C,
0x39,0,4,0xB6,0x00,0x00,0x00,
0x39,0,2,0x6F,0x0F,
0x39,0,4,0xB6,0x0C,0xDA,0xA0,
0x39,0,2,0x6F,0x00,
0x39,0,4,0xB8,0x0C,0xDB,0x00,
0x39,0,2,0x6F,0x03,
0x39,0,3,0xB8,0x00,0xE2,
0x39,0,2,0x6F,0x05,
0x39,0,4,0xB8,0x0C,0xDC,0x00,
0x39,0,2,0x6F,0x08,
0x39,0,3,0xB8,0x05,0x85,
0x39,0,2,0x6F,0x0A,
0x39,0,4,0xB8,0x0C,0xE2,0x00,
0x39,0,2,0x6F,0x0D,
0x39,0,3,0xB8,0x0B,0x7C,
0x39,0,2,0x6F,0x0F,
0x39,0,4,0xB8,0x0C,0xEE,0x00,
0x39,0,2,0x6F,0x12,
0x39,0,3,0xB8,0x00,0xAC,
0x39,0,2,0x6F,0x14,
0x39,0,4,0xB8,0x0C,0xEF,0x00,
0x39,0,2,0x6F,0x17,
0x39,0,3,0xB8,0x00,0xAC,
0x39,0,2,0x6F,0x19,
0x39,0,4,0xB8,0x0C,0xF0,0x00,
0x39,0,2,0x6F,0x1C,
0x39,0,3,0xB8,0x00,0xAC,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x07,
0x39,0,2,0x6F,0x37,
0x39,0,4,0xB7,0x08,0x08,0x08,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x05,
0x39,0,4,0xB0,0x83,0x21,0x01,
0x39,0,3,0xB3,0x86,0x83,
0x39,0,3,0xB5,0x85,0x85,
0x39,0,5,0xB7,0x85,0x00,0x20,0x84,
0x39,0,5,0xB8,0x85,0x00,0x20,0x84,
0x39,0,10,0xC0,0x86,0x00,0x80,0x00,0x00,0x00,0xD0,0x00,0x00,
0x39,0,3,0xC7,0x03,0x01,
0x39,0,5,0xE0,0x02,0x09,0x68,0x00,
0x39,0,5,0xE1,0x02,0x09,0x68,0x02,
0x39,0,2,0xCA,0x13,
0x39,0,3,0xCB,0x03,0x03,
0x39,0,2,0xD7,0x13,
0x39,0,2,0xD8,0x13,
0x39,0,2,0xD9,0x40,
0x39,0,2,0x6F,0x03,
0x39,0,2,0xEC,0x11,
0x39,0,2,0x6F,0x06,
0x39,0,2,0xEC,0x1B,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x06,
0x39,0,6,0xB0,0x19,0x38,0x18,0x38,0x08,
0x39,0,6,0xB1,0x38,0x14,0x38,0x00,0x38,
0x39,0,6,0xB2,0x38,0x38,0x38,0x38,0x38,
0x39,0,6,0xB3,0x38,0x15,0x38,0x38,0x38,
0x39,0,6,0xB6,0x19,0x38,0x18,0x38,0x08,
0x39,0,6,0xB7,0x38,0x14,0x38,0x00,0x38,
0x39,0,6,0xB8,0x38,0x38,0x38,0x38,0x38,
0x39,0,6,0xB9,0x38,0x15,0x38,0x38,0x38,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x07,
0x39,0,7,0xB1,0x18,0x08,0x00,0x08,0x18,0x00,
0x39,0,2,0x6F,0x12,
0x39,0,2,0xB2,0xF0,
0x39,0,2,0x6F,0x2D,
0x39,0,2,0xB2,0xCC,
0x39,0,2,0x6F,0x3F,
0x39,0,2,0xB2,0x04,
0x39,0,2,0x6F,0x51,
0x39,0,2,0xB2,0x04,
0x39,0,2,0x6F,0x5A,
0x39,0,2,0xB2,0x03,
0x39,0,2,0x6F,0x63,
0x39,0,2,0xB2,0x9B,
0x39,0,2,0x6F,0x75,
0x39,0,2,0xB2,0x04,
0x39,0,2,0x6F,0x87,
0x39,0,2,0xB2,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,2,0xB2,0x03,
0x39,0,2,0x6F,0x99,
0x39,0,2,0xB2,0x3A,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x08,
0x39,0,3,0xC1,0x8E,0xFF,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x09,
0x39,0,2,0xB0,0x00,
0x39,0,2,0xB0,0x01,
0x39,0,25,0xC3,0x00,0x00,0x00,0xCB,0xA9,0x90,0x00,0x00,0x00,0x00,0x40,0x20,0x00,0x00,0x00,0x00,0x70,0x25,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xC3,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xC3,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xC4,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xC4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xC5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xC6,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xC6,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,25,0xC7,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xC7,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xC7,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xC7,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xC7,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x0C,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xC7,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x10,
0x39,0,2,0x6F,0x90,
0x39,0,7,0xC7,0x00,0x00,0x00,0x00,0x00,0x18,
0x39,0,25,0xCC,0x00,0x00,0x00,0xCB,0xA9,0x90,0x00,0x00,0x00,0x00,0x50,0x2C,0x00,0x00,0x00,0x00,0x20,0x27,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xCC,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xCC,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xCD,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xCD,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x90,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xA8,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xC0,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xD8,
0x39,0,25,0xCF,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0xF0,
0x39,0,13,0xCF,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,25,0xD0,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xD0,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xD0,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x04,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xD0,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xD0,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x0C,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xD0,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x10,
0x39,0,2,0x6F,0x90,
0x39,0,7,0xD0,0x00,0x00,0x00,0x00,0x00,0x18,
0x39,0,2,0xB0,0x00,
0x39,0,25,0xD5,0x80,0x00,0x48,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xD5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xD5,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x9A,0x8C,0x78,0x00,0x00,0x00,0x99,0x09,0xCC,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xD5,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x99,0x0C,0xC9,0x90,0x78,0x99,0x09,0xCC,0x64,0x46,
0x39,0,25,0xD6,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xD6,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xD6,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0xFF,0xFF,0xFF,0x00,0x00,0x00,0xFF,0xFF,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xD6,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xD6,0x00,0xE0,0xE0,0xE0,0xC0,0xC0,0xC0,0xA0,0xA0,0xA0,0x80,0x80,0x80,0x60,0x60,0x60,0x40,0x40,0x40,0x20,0x20,0x20,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xD6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x90,
0x39,0,2,0xD6,0x00,
0x39,0,25,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,9,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,25,0xD8,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,25,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x48,
0x39,0,25,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x60,
0x39,0,25,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x78,
0x39,0,25,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x90,
0x39,0,19,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,25,0xD9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x18,
0x39,0,25,0xD9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x30,
0x39,0,9,0xD9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x07,
0x39,0,2,0xBE,0x80,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0x6F,0x01,
0x39,0,2,0xCD,0x07,
0x39,0,2,0x6F,0x07,
0x39,0,3,0x51,0x8F,0xFF,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x07,
0x39,0,4,0xC0,0x87,0x01,0x08,
0x39,0,2,0x6F,0x03,
0x39,0,15,0xC0,0x00,0x00,0x00,0x55,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC1,0x31,0x0F,0x04,0x41,0x04,0x00,0xF7,0xC0,0x3F,0xFE,0xBB,0xB0,0x3F,0xFE,0xC3,0xF0,0x80,0x00,0x19,0x5A,0xC1,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC1,0x05,0x22,0x05,0x2A,0x00,0x23,0x46,0x35,0xF0,0xDD,0xDC,0x04,0xEC,0x30,0xFF,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC1,0x00,0x11,0x21,0x00,0x10,0x23,0x00,0x00,0x00,0x05,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC2,0x3D,0x00,0x03,0xC1,0x04,0x00,0x07,0xC0,0x3F,0xFD,0xBF,0x88,0x00,0x00,0x22,0xF0,0x80,0x00,0x02,0x44,0x39,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC2,0x1D,0x22,0x05,0x2A,0x00,0x47,0x6A,0x35,0xC0,0xDD,0x24,0x00,0x00,0x30,0xFF,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC2,0x00,0x1B,0x21,0xAA,0x68,0x6C,0x00,0x00,0x00,0x1D,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC3,0x37,0x00,0x04,0x41,0x04,0x41,0x08,0x82,0x00,0x00,0x12,0x90,0x3F,0xFD,0x76,0x50,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC3,0x05,0x22,0x9C,0xC2,0x00,0x23,0x46,0x35,0x30,0x23,0xDB,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC3,0x44,0xA6,0xAA,0x00,0x20,0x23,0x00,0x00,0x00,0x05,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC4,0x3B,0x0F,0x03,0xC1,0x04,0x00,0xF8,0x40,0x00,0x01,0x32,0x30,0x00,0x01,0x39,0xF0,0xFF,0xFF,0xC1,0xF0,0x30,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC4,0x1D,0x22,0x9D,0xC2,0x00,0x47,0x6A,0x35,0x0F,0x23,0x24,0xFB,0x14,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC4,0x44,0xA6,0xAA,0xAA,0x68,0x6B,0x00,0x00,0x00,0x1D,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC5,0x30,0x0F,0x04,0xC9,0x0D,0x99,0xEF,0xDE,0x3F,0xFB,0xA0,0x46,0x3F,0xF6,0xD4,0x8A,0x80,0x00,0xFF,0xE0,0x01,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC5,0x1E,0x00,0x22,0x97,0x00,0x00,0x23,0x33,0xF0,0xDD,0x8B,0x0F,0xFF,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC5,0x22,0x29,0x9C,0x00,0x23,0x25,0x00,0x00,0x00,0x1E,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC6,0x38,0x0F,0x0A,0xF9,0x04,0x41,0xF2,0x56,0x3F,0xF7,0x36,0x96,0x3F,0xFB,0xFA,0x8E,0x80,0x00,0xF3,0x49,0x71,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC6,0x79,0x00,0x00,0x21,0x00,0x24,0x9D,0x33,0xF0,0x87,0xDF,0x0F,0x99,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC6,0x22,0x27,0x9E,0x00,0x68,0x6A,0x00,0x00,0x00,0x79,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC7,0x2C,0x00,0x0A,0x29,0x04,0x41,0x0D,0x26,0x3F,0xF1,0x1A,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC7,0x79,0x00,0x00,0x21,0x9A,0xEE,0x67,0x33,0xC0,0x87,0x21,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x79,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC8,0x2C,0x00,0x04,0xC9,0x0D,0x99,0x10,0x22,0x3F,0xF9,0x6B,0xA0,0x00,0x05,0x73,0xA0,0x80,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC8,0x04,0x00,0x22,0x97,0xAA,0x68,0x8B,0x33,0xC0,0xDD,0x75,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xC9,0x26,0x00,0x04,0xC9,0x0D,0x99,0x10,0x22,0x00,0x00,0x00,0x00,0x3F,0xEF,0x75,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xC9,0x1E,0x44,0x30,0xA5,0x00,0x00,0x23,0x33,0x30,0x23,0x8B,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xC9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1E,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xCA,0x2E,0x00,0x0A,0x29,0x04,0x41,0x0D,0x26,0x00,0x06,0x10,0x08,0x3F,0xFA,0x48,0xA8,0x80,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xCA,0x79,0x44,0xA6,0xC7,0x00,0x24,0x9D,0x33,0x30,0x79,0xDF,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xCA,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x79,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xCB,0x2A,0x0F,0x0A,0x29,0x04,0x41,0xF2,0xDA,0x00,0x0C,0x46,0xFE,0x00,0x01,0xB1,0xE6,0xFF,0xFE,0x3F,0xA0,0xD9,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xCB,0x79,0x44,0xA6,0xC7,0x9A,0xEE,0x67,0x33,0x0F,0x79,0x21,0xF0,0x67,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xCB,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x79,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xCC,0x2A,0x0F,0x04,0xC9,0x0D,0x99,0xEF,0xDE,0x00,0x02,0x34,0xA6,0x00,0x0C,0xD3,0x2A,0x7F,0xFD,0xFE,0x10,0x21,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xCC,0x04,0x44,0x30,0xA5,0xAA,0x68,0x8B,0x33,0x0F,0x23,0x75,0xF0,0x01,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xCC,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xCD,0x21,0x00,0x21,0xC9,0x21,0xC9,0x00,0x00,0x3F,0xE7,0x73,0xF6,0x3F,0xE7,0x73,0xF6,0x80,0x04,0xA6,0xCB,0x77,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xCD,0x1B,0x22,0x05,0x63,0x99,0x0B,0x69,0x77,0xF0,0xA3,0xA3,0x21,0xC9,0xF0,0xFF,0xFF,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xCD,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1B,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xCE,0x27,0x00,0x21,0xC9,0x21,0xC9,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0xE7,0x73,0xF6,0x80,0x00,0x18,0xAD,0xD3,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xCE,0x1B,0x22,0x64,0xC2,0x99,0x0B,0x69,0x77,0x30,0x5D,0xA3,0x00,0x00,0xC0,0x00,0xFF,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xCE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1B,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xCF,0x2B,0x00,0x21,0xC9,0x21,0xC9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,0xFB,0x8A,0x90,0x2F,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xCF,0x41,0x22,0x64,0xC2,0x99,0x6A,0xC8,0x77,0x0F,0x5D,0x5D,0xDE,0x37,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xCF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD0,0x2D,0x00,0x21,0xC9,0x21,0xC9,0x00,0x00,0x3F,0xE7,0x73,0xF6,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xAD,0xD3,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD0,0x41,0x22,0x05,0x63,0x99,0x6A,0xC8,0x77,0xC0,0xA3,0x5D,0x00,0x00,0x30,0xFF,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x40,0x40,0x40,0x40,0x40,0x40,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xD9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xD9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xD9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x00,
0x39,0,22,0xEA,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x15,
0x39,0,17,0xEA,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,2,0x6F,0x25,
0x39,0,17,0xEA,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x00,
0x39,0,2,0x6F,0x13,
0x39,0,25,0xDF,0x02,0x63,0x09,0x69,0x00,0x00,0x00,0x00,0x02,0x05,0x09,0x0B,0x02,0xC2,0x09,0xC8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x00,
0x39,0,2,0xDF,0x00,
0x39,0,2,0x6F,0x02,
0x39,0,2,0xDF,0x11,
0x39,0,2,0x6F,0x33,
0x39,0,2,0xDF,0x00,
0x39,0,2,0x6F,0x35,
0x39,0,2,0xDF,0x00,
0x39,0,2,0x6F,0x37,
0x39,0,2,0xDF,0x00,
0x39,0,2,0x6F,0x38,
0x39,0,3,0xDF,0x00,0x10,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x00,
0x39,0,2,0x6F,0x31,
0x39,0,2,0xDF,0x23,
0x39,0,2,0x6F,0x4C,
0x39,0,3,0xDF,0x36,0xEC,
0x39,0,2,0x6F,0x50,
0x39,0,3,0xDF,0x3F,0xFF,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,7,0xD0,0x0A,0x6C,0x09,0x90,0x0C,0x16,
0x39,0,2,0x6F,0x01,
0x39,0,3,0x87,0x0D,0xBB,
0x39,0,2,0x88,0x01,
0x39,0,2,0x6F,0x01,
0x39,0,5,0x88,0x01,0x54,0x06,0xBB,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x01,
0x39,0,2,0x6F,0x05,
0x39,0,4,0xC5,0x15,0x15,0x15,
0x39,0,5,0xFF,0xAA,0x55,0xA5,0x80,
0x39,0,2,0x6F,0x1B,
0x39,0,2,0xF4,0x55,
0x39,0,5,0xFF,0xAA,0x55,0xA5,0x81,
0x39,0,2,0x6F,0x18,
0x39,0,2,0xFB,0x04,
0x39,0,5,0xFF,0xAA,0x55,0xA5,0x81,
0x39,0,2,0x6F,0x19,
0x39,0,2,0xFB,0x00,
0x39,0,5,0xFF,0xAA,0x55,0xA5,0x80,
0x39,0,2,0x6F,0x1A,
0x39,0,2,0xF4,0x55,
0x39,0,5,0xFF,0xAA,0x55,0xA5,0x83,
0x39,0,2,0x6F,0x12,
0x39,0,2,0xFE,0x41,
0x39,0,5,0xFF,0xAA,0x55,0xA5,0x80,
0x39,0,2,0x6F,0x31,
0x39,0,3,0xF8,0x01,0x09,
0x39,0,2,0x6F,0x15,
0x39,0,3,0xF8,0x01,0x5E,
0x39,0,2,0x6F,0x18,
0x39,0,2,0xF4,0x30,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xCC,0x30,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xBF,0x0B,
0x39,0,19,0xB0,0x00,0x00,0x01,0x27,0x01,0x84,0x01,0xE1,0x02,0x3D,0x02,0xB2,0x03,0x09,0x03,0x5F,0x03,0xA1,
0x39,0,19,0xB1,0x04,0x21,0x04,0x87,0x04,0xEC,0x05,0x3D,0x05,0x8D,0x06,0x0C,0x06,0x89,0x06,0xFB,0x07,0x6B,
0x39,0,15,0xB2,0x08,0x38,0x08,0xEF,0x09,0xAA,0x0A,0x0E,0x0A,0x3E,0x0A,0x6C,0x0A,0x6C,
0x39,0,19,0xB3,0x00,0x00,0x00,0x81,0x01,0x17,0x01,0x75,0x01,0xD1,0x02,0x4C,0x02,0xA4,0x02,0xFA,0x03,0x39,
0x39,0,19,0xB4,0x03,0xB5,0x04,0x15,0x04,0x73,0x04,0xBF,0x05,0x0A,0x05,0x82,0x05,0xF9,0x06,0x62,0x06,0xCA,
0x39,0,15,0xB5,0x07,0x87,0x08,0x31,0x08,0xE2,0x09,0x3A,0x09,0x65,0x09,0x90,0x09,0x90,
0x39,0,19,0xB6,0x00,0x00,0x00,0xFF,0x01,0x83,0x01,0xF1,0x02,0x5E,0x03,0x00,0x03,0x6F,0x03,0xDD,0x04,0x2D,
0x39,0,19,0xB7,0x04,0xCA,0x05,0x3E,0x05,0xB1,0x06,0x0E,0x06,0x69,0x06,0xF9,0x07,0x87,0x08,0x09,0x08,0x8A,
0x39,0,15,0xB8,0x09,0x70,0x0A,0x4A,0x0B,0x2B,0x0B,0x9F,0x0B,0xD8,0x0C,0x16,0x0C,0x16,
0x39,0,2,0xBF,0x0A,
0x39,0,19,0xB0,0x00,0x00,0x01,0x65,0x01,0xAA,0x01,0xEF,0x02,0x32,0x02,0x9C,0x02,0xEC,0x03,0x3A,0x03,0x77,
0x39,0,19,0xB1,0x03,0xEE,0x04,0x4C,0x04,0xA8,0x04,0xF0,0x05,0x36,0x05,0xB1,0x06,0x2B,0x06,0x90,0x06,0xF3,
0x39,0,15,0xB2,0x07,0xA6,0x08,0x4D,0x08,0xE7,0x09,0x37,0x09,0x5E,0x09,0x88,0x09,0x88,
0x39,0,19,0xB3,0x00,0x00,0x01,0x00,0x01,0x5B,0x01,0x94,0x01,0xCC,0x02,0x36,0x02,0x83,0x02,0xCE,0x03,0x0A,
0x39,0,19,0xB4,0x03,0x7F,0x03,0xD9,0x04,0x32,0x04,0x77,0x04,0xBA,0x05,0x2D,0x05,0x9F,0x05,0xFE,0x06,0x5B,
0x39,0,15,0xB5,0x07,0x00,0x07,0x9A,0x08,0x2B,0x08,0x75,0x08,0x99,0x08,0xBF,0x08,0xBF,
0x39,0,19,0xB6,0x00,0x00,0x01,0x40,0x01,0xA3,0x01,0xF6,0x02,0x47,0x02,0xD4,0x03,0x3C,0x03,0xA3,0x03,0xEF,
0x39,0,19,0xB7,0x04,0x85,0x04,0xF3,0x05,0x60,0x05,0xB1,0x06,0x00,0x06,0x8B,0x07,0x14,0x07,0x87,0x07,0xF8,
0x39,0,15,0xB8,0x08,0xC5,0x09,0x86,0x0A,0x3E,0x0A,0x9D,0x0A,0xCB,0x0A,0xFD,0x0A,0xFD,
0x39,0,2,0xBF,0x09,
0x39,0,19,0xB0,0x00,0x00,0x01,0x97,0x01,0xCF,0x02,0x07,0x02,0x3F,0x02,0x98,0x02,0xEF,0x03,0x37,0x03,0x6D,
0x39,0,19,0xB1,0x03,0xD5,0x04,0x32,0x04,0x81,0x04,0xCB,0x05,0x0F,0x05,0x82,0x05,0xE8,0x06,0x49,0x06,0xA1,
0x39,0,15,0xB2,0x07,0x4B,0x07,0xE4,0x08,0x77,0x08,0xBB,0x08,0xDE,0x09,0x00,0x09,0x00,
0x39,0,19,0xB3,0x00,0x00,0x01,0x0E,0x01,0x5C,0x01,0xAA,0x01,0xDB,0x02,0x30,0x02,0x88,0x02,0xCA,0x03,0x05,
0x39,0,19,0xB4,0x03,0x66,0x03,0xC2,0x04,0x0A,0x04,0x52,0x04,0x90,0x04,0xFA,0x05,0x5D,0x05,0xB4,0x06,0x06,
0x39,0,15,0xB5,0x06,0xA5,0x07,0x2D,0x07,0xB2,0x07,0xF2,0x08,0x12,0x08,0x31,0x08,0x31,
0x39,0,19,0xB6,0x00,0x00,0x01,0x50,0x01,0xA8,0x02,0x00,0x02,0x4A,0x02,0xC3,0x03,0x38,0x03,0x8E,0x03,0xDC,
0x39,0,19,0xB7,0x04,0x5C,0x04,0xCC,0x05,0x26,0x05,0x7C,0x05,0xC9,0x06,0x4A,0x06,0xC2,0x07,0x2A,0x07,0x8D,
0x39,0,15,0xB8,0x08,0x4E,0x08,0xF8,0x09,0xA0,0x09,0xF4,0x0A,0x1D,0x0A,0x45,0x0A,0x45,
0x39,0,2,0xBF,0x08,
0x39,0,19,0xB0,0x00,0x00,0x01,0x9C,0x01,0xC8,0x01,0xF4,0x02,0x20,0x02,0x7D,0x02,0xC6,0x03,0x04,0x03,0x3F,
0x39,0,19,0xB1,0x03,0xA4,0x03,0xF9,0x04,0x47,0x04,0x85,0x04,0xC3,0x05,0x34,0x05,0x99,0x05,0xF6,0x06,0x47,
0x39,0,15,0xB2,0x06,0xE1,0x07,0x6E,0x07,0xF1,0x08,0x30,0x08,0x4E,0x08,0x6F,0x08,0x6F,
0x39,0,19,0xB3,0x00,0x00,0x01,0x57,0x01,0x80,0x01,0xA9,0x01,0xC3,0x02,0x17,0x02,0x5F,0x02,0xA0,0x02,0xD8,
0x39,0,19,0xB4,0x03,0x39,0x03,0x89,0x03,0xD2,0x04,0x0F,0x04,0x4B,0x04,0xB4,0x05,0x11,0x05,0x69,0x05,0xB1,
0x39,0,15,0xB5,0x06,0x41,0x06,0xC2,0x07,0x38,0x07,0x73,0x07,0x8E,0x07,0xAD,0x07,0xAD,
0x39,0,19,0xB6,0x00,0x00,0x01,0x81,0x01,0xBB,0x01,0xF5,0x02,0x26,0x02,0x9E,0x02,0xFE,0x03,0x55,0x03,0xA1,
0x39,0,19,0xB7,0x04,0x1E,0x04,0x87,0x04,0xE2,0x05,0x2C,0x05,0x75,0x05,0xF2,0x06,0x63,0x06,0xCE,0x07,0x23,
0x39,0,15,0xB8,0x07,0xD5,0x08,0x73,0x09,0x08,0x09,0x52,0x09,0x73,0x09,0x97,0x09,0x97,
0x39,0,2,0xBF,0x07,
0x39,0,19,0xB0,0x00,0x00,0x01,0x68,0x01,0x9B,0x01,0xCE,0x02,0x01,0x02,0x55,0x02,0x97,0x02,0xCC,0x03,0x04,
0x39,0,19,0xB1,0x03,0x5C,0x03,0xAB,0x03,0xEE,0x04,0x2D,0x04,0x67,0x04,0xD4,0x05,0x2D,0x05,0x7D,0x05,0xCC,
0x39,0,15,0xB2,0x06,0x54,0x06,0xD4,0x07,0x47,0x07,0x81,0x07,0x9C,0x07,0xB3,0x07,0xB3,
0x39,0,19,0xB3,0x00,0x00,0x01,0x22,0x01,0x56,0x01,0x8A,0x01,0xAB,0x01,0xEE,0x02,0x30,0x02,0x67,0x02,0x99,
0x39,0,19,0xB4,0x02,0xF2,0x03,0x44,0x03,0x7F,0x03,0xBE,0x03,0xF2,0x04,0x5A,0x04,0xAA,0x04,0xF7,0x05,0x40,
0x39,0,15,0xB5,0x05,0xBE,0x06,0x33,0x06,0x9D,0x06,0xD0,0x06,0xE9,0x07,0x01,0x07,0x01,
0x39,0,19,0xB6,0x00,0x00,0x01,0x53,0x01,0x90,0x01,0xCD,0x02,0x00,0x02,0x68,0x02,0xC1,0x03,0x08,0x03,0x4E,
0x39,0,19,0xB7,0x03,0xC4,0x04,0x2B,0x04,0x77,0x04,0xC5,0x05,0x07,0x05,0x85,0x05,0xE8,0x06,0x46,0x06,0x9F,
0x39,0,15,0xB8,0x07,0x35,0x07,0xC3,0x08,0x44,0x08,0x87,0x08,0xA5,0x08,0xC1,0x08,0xC1,
0x39,0,2,0xBF,0x06,
0x39,0,19,0xB0,0x00,0x00,0x01,0x7E,0x01,0x99,0x01,0xB4,0x01,0xCF,0x02,0x0F,0x02,0x47,0x02,0x74,0x02,0xA0,
0x39,0,19,0xB1,0x02,0xEE,0x03,0x2C,0x03,0x69,0x03,0x9C,0x03,0xCD,0x04,0x22,0x04,0x75,0x04,0xB9,0x04,0xFB,
0x39,0,15,0xB2,0x05,0x72,0x05,0xDA,0x06,0x38,0x06,0x66,0x06,0x7C,0x06,0x92,0x06,0x92,
0x39,0,19,0xB3,0x00,0x00,0x01,0x83,0x01,0x87,0x01,0x8B,0x01,0x8E,0x01,0xB7,0x01,0xE5,0x02,0x10,0x02,0x39,
0x39,0,19,0xB4,0x02,0x85,0x02,0xC3,0x03,0x00,0x03,0x31,0x03,0x60,0x03,0xB0,0x03,0xFF,0x04,0x40,0x04,0x80,
0x39,0,15,0xB5,0x04,0xEE,0x05,0x4F,0x05,0xA5,0x05,0xCF,0x05,0xE3,0x05,0xF6,0x05,0xF6,
0x39,0,19,0xB6,0x00,0x00,0x01,0x8D,0x01,0xA3,0x01,0xB9,0x01,0xCC,0x02,0x16,0x02,0x59,0x02,0x93,0x02,0xCC,
0x39,0,19,0xB7,0x03,0x35,0x03,0x87,0x03,0xD7,0x04,0x15,0x04,0x52,0x04,0xB6,0x05,0x19,0x05,0x69,0x05,0xB7,
0x39,0,15,0xB8,0x06,0x3A,0x06,0xB1,0x07,0x18,0x07,0x4C,0x07,0x64,0x07,0x7B,0x07,0x7B,
0x39,0,2,0xBF,0x05,
0x39,0,19,0xB0,0x00,0x00,0x01,0x34,0x01,0x55,0x01,0x76,0x01,0x97,0x01,0xD7,0x02,0x18,0x02,0x57,0x02,0x84,
0x39,0,19,0xB1,0x02,0xDB,0x03,0x23,0x03,0x59,0x03,0x93,0x03,0xCC,0x04,0x1E,0x04,0x6F,0x04,0xB6,0x04,0xFB,
0x39,0,15,0xB2,0x05,0x72,0x05,0xD5,0x06,0x35,0x06,0x63,0x06,0x7A,0x06,0x8F,0x06,0x8F,
0x39,0,19,0xB3,0x00,0x00,0x01,0x4E,0x01,0x67,0x01,0x80,0x01,0x90,0x01,0xAE,0x01,0xDA,0x02,0x05,0x02,0x2D,
0x39,0,19,0xB4,0x02,0x7A,0x02,0xBD,0x02,0xF0,0x03,0x29,0x03,0x5E,0x03,0xAE,0x03,0xFC,0x04,0x3D,0x04,0x7C,
0x39,0,15,0xB5,0x04,0xEA,0x05,0x4A,0x05,0xA1,0x05,0xCB,0x05,0xE0,0x05,0xF2,0x05,0xF2,
0x39,0,19,0xB6,0x00,0x00,0x01,0x43,0x01,0x6E,0x01,0x99,0x01,0xBD,0x02,0x01,0x02,0x46,0x02,0x89,0x02,0xBF,
0x39,0,19,0xB7,0x03,0x28,0x03,0x82,0x03,0xC6,0x04,0x0E,0x04,0x52,0x04,0xB5,0x05,0x17,0x05,0x65,0x05,0xB1,
0x39,0,15,0xB8,0x06,0x39,0x06,0xAE,0x07,0x14,0x07,0x46,0x07,0x5F,0x07,0x78,0x07,0x78,
0x39,0,2,0xBF,0x04,
0x39,0,19,0xB0,0x00,0x00,0x01,0x6A,0x01,0x85,0x01,0xA0,0x01,0xBB,0x01,0xF1,0x02,0x24,0x02,0x56,0x02,0x82,
0x39,0,19,0xB1,0x02,0xD8,0x03,0x18,0x03,0x57,0x03,0x8B,0x03,0xBD,0x04,0x14,0x04,0x69,0x04,0xAC,0x04,0xEE,
0x39,0,15,0xB2,0x05,0x61,0x05,0xC7,0x06,0x26,0x06,0x52,0x06,0x67,0x06,0x7B,0x06,0x7B,
0x39,0,19,0xB3,0x00,0x00,0x01,0x53,0x01,0x6C,0x01,0x85,0x01,0x9E,0x01,0xBE,0x01,0xE3,0x02,0x06,0x02,0x2D,
0x39,0,19,0xB4,0x02,0x77,0x02,0xB5,0x02,0xF1,0x03,0x21,0x03,0x4F,0x03,0xA2,0x03,0xF4,0x04,0x34,0x04,0x73,
0x39,0,15,0xB5,0x04,0xE1,0x05,0x3B,0x05,0x94,0x05,0xBC,0x05,0xCF,0x05,0xE1,0x05,0xE1,
0x39,0,19,0xB6,0x00,0x00,0x01,0x74,0x01,0x97,0x01,0xBA,0x01,0xDD,0x02,0x18,0x02,0x54,0x02,0x8E,0x02,0xC2,
0x39,0,19,0xB7,0x03,0x27,0x03,0x77,0x03,0xC6,0x04,0x05,0x04,0x42,0x04,0xA9,0x05,0x0E,0x05,0x5B,0x05,0xA6,
0x39,0,15,0xB8,0x06,0x2C,0x06,0x98,0x07,0x05,0x07,0x37,0x07,0x4E,0x07,0x63,0x07,0x63,
0x39,0,2,0xBF,0x03,
0x39,0,19,0xB0,0x00,0x00,0x02,0x04,0x02,0x0A,0x02,0x10,0x02,0x16,0x02,0x22,0x02,0x2E,0x02,0x58,0x02,0x80,
0x39,0,19,0xB1,0x02,0xD4,0x03,0x10,0x03,0x4B,0x03,0x82,0x03,0xB7,0x04,0x07,0x04,0x55,0x04,0x98,0x04,0xDA,
0x39,0,15,0xB2,0x05,0x4D,0x05,0xB2,0x06,0x0C,0x06,0x37,0x06,0x4B,0x06,0x60,0x06,0x60,
0x39,0,19,0xB3,0x00,0x00,0x01,0xF6,0x01,0xF6,0x01,0xF6,0x01,0xF6,0x01,0xF6,0x01,0xF6,0x02,0x19,0x02,0x3A,
0x39,0,19,0xB4,0x02,0x7C,0x02,0xB3,0x02,0xE8,0x03,0x1C,0x03,0x4F,0x03,0x9A,0x03,0xE4,0x04,0x24,0x04,0x63,
0x39,0,15,0xB5,0x04,0xCC,0x05,0x29,0x05,0x7B,0x05,0xA3,0x05,0xB6,0x05,0xC9,0x05,0xC9,
0x39,0,19,0xB6,0x00,0x00,0x01,0xF5,0x02,0x04,0x02,0x13,0x02,0x22,0x02,0x40,0x02,0x59,0x02,0x8D,0x02,0xBF,
0x39,0,19,0xB7,0x03,0x23,0x03,0x6D,0x03,0xB6,0x03,0xF9,0x04,0x3B,0x04,0x99,0x04,0xF6,0x05,0x46,0x05,0x94,
0x39,0,15,0xB8,0x06,0x13,0x06,0x85,0x06,0xE7,0x07,0x18,0x07,0x2F,0x07,0x46,0x07,0x46,
0x39,0,2,0xBF,0x02,
0x39,0,19,0xB0,0x00,0x00,0x01,0xB9,0x01,0xD0,0x01,0xE7,0x01,0xFE,0x02,0x2C,0x02,0x5A,0x02,0x74,0x02,0x8C,
0x39,0,19,0xB1,0x02,0xCD,0x03,0x06,0x03,0x3D,0x03,0x6E,0x03,0x9D,0x03,0xEE,0x04,0x3D,0x04,0x7D,0x04,0xBC,
0x39,0,15,0xB2,0x05,0x2A,0x05,0x8A,0x05,0xE1,0x06,0x0B,0x06,0x1F,0x06,0x30,0x06,0x30,
0x39,0,19,0xB3,0x00,0x00,0x01,0x9C,0x01,0xB5,0x01,0xCE,0x01,0xE7,0x02,0x1A,0x02,0x3A,0x02,0x4A,0x02,0x59,
0x39,0,19,0xB4,0x02,0x86,0x02,0xB6,0x02,0xE4,0x03,0x10,0x03,0x3B,0x03,0x88,0x03,0xD3,0x04,0x0E,0x04,0x48,
0x39,0,15,0xB5,0x04,0xAD,0x05,0x07,0x05,0x57,0x05,0x7D,0x05,0x8F,0x05,0x9F,0x05,0x9F,
0x39,0,19,0xB6,0x00,0x00,0x01,0xCE,0x01,0xEA,0x02,0x06,0x02,0x22,0x02,0x5A,0x02,0x89,0x02,0xAB,0x02,0xCC,
0x39,0,19,0xB7,0x03,0x1A,0x03,0x61,0x03,0xA7,0x03,0xE2,0x04,0x1B,0x04,0x7C,0x04,0xDB,0x05,0x26,0x05,0x70,
0x39,0,15,0xB8,0x05,0xE9,0x06,0x59,0x06,0xBA,0x06,0xEA,0x07,0x00,0x07,0x13,0x07,0x13,
0x39,0,2,0xBF,0x01,
0x39,0,19,0xB0,0x00,0x00,0x02,0x2A,0x02,0x33,0x02,0x3C,0x02,0x45,0x02,0x58,0x02,0x6B,0x02,0x7E,0x02,0x94,
0x39,0,19,0xB1,0x02,0xC5,0x02,0xF2,0x03,0x1D,0x03,0x4C,0x03,0x79,0x03,0xC6,0x04,0x11,0x04,0x4F,0x04,0x8B,
0x39,0,15,0xB2,0x04,0xF3,0x05,0x4F,0x05,0xA2,0x05,0xCA,0x05,0xDC,0x05,0xEC,0x05,0xEC,
0x39,0,19,0xB3,0x00,0x00,0x02,0x12,0x02,0x1A,0x02,0x22,0x02,0x2A,0x02,0x3B,0x02,0x4C,0x02,0x57,0x02,0x6B,
0x39,0,19,0xB4,0x02,0x91,0x02,0xB5,0x02,0xD7,0x02,0xFF,0x03,0x25,0x03,0x6C,0x03,0xB1,0x03,0xEA,0x04,0x21,
0x39,0,15,0xB5,0x04,0x80,0x04,0xD5,0x05,0x1F,0x05,0x43,0x05,0x54,0x05,0x63,0x05,0x63,
0x39,0,19,0xB6,0x00,0x00,0x02,0x37,0x02,0x44,0x02,0x51,0x02,0x5E,0x02,0x79,0x02,0x94,0x02,0xAB,0x02,0xCB,
0x39,0,19,0xB7,0x03,0x0D,0x03,0x49,0x03,0x83,0x03,0xBB,0x03,0xF2,0x04,0x4D,0x04,0xA6,0x04,0xEF,0x05,0x37,
0x39,0,15,0xB8,0x05,0xAE,0x06,0x17,0x06,0x73,0x06,0xA0,0x06,0xB5,0x06,0xC7,0x06,0xC7,
0x39,0,2,0xBF,0x00,
0x39,0,19,0xB0,0x00,0x00,0x02,0x68,0x02,0x6D,0x02,0x72,0x02,0x77,0x02,0x82,0x02,0x8D,0x02,0x98,0x02,0xA3,
0x39,0,19,0xB1,0x02,0xBA,0x02,0xDE,0x02,0xFA,0x03,0x19,0x03,0x3E,0x03,0x7C,0x03,0xB8,0x03,0xEE,0x04,0x23,
0x39,0,15,0xB2,0x04,0x7F,0x04,0xD1,0x05,0x1B,0x05,0x3E,0x05,0x4E,0x05,0x5F,0x05,0x5F,
0x39,0,19,0xB3,0x00,0x00,0x02,0x8C,0x02,0x8C,0x02,0x8C,0x02,0x8C,0x02,0x8D,0x02,0x8E,0x02,0x8F,0x02,0x90,
0x39,0,19,0xB4,0x02,0x92,0x02,0xAF,0x02,0xC7,0x02,0xE1,0x03,0x00,0x03,0x31,0x03,0x68,0x03,0x9A,0x03,0xCB,
0x39,0,15,0xB5,0x04,0x20,0x04,0x6B,0x04,0xAD,0x04,0xCB,0x04,0xD9,0x04,0xE6,0x04,0xE6,
0x39,0,19,0xB6,0x00,0x00,0x02,0x81,0x02,0x89,0x02,0x91,0x02,0x99,0x02,0xA9,0x02,0xB9,0x02,0xC9,0x02,0xD9,
0x39,0,19,0xB7,0x02,0xF4,0x03,0x21,0x03,0x47,0x03,0x74,0x03,0xA5,0x03,0xF2,0x04,0x3B,0x04,0x7B,0x04,0xBA,
0x39,0,15,0xB8,0x05,0x27,0x05,0x88,0x05,0xDB,0x06,0x01,0x06,0x13,0x06,0x25,0x06,0x25,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xBF,0x1B,
0x39,0,19,0xB0,0x00,0x00,0x01,0x9C,0x01,0xE3,0x02,0x2A,0x02,0x70,0x02,0xDE,0x03,0x2A,0x03,0x74,0x03,0xB5,
0x39,0,19,0xB1,0x04,0x35,0x04,0x92,0x04,0xEE,0x05,0x3B,0x05,0x87,0x06,0x06,0x06,0x84,0x06,0xF1,0x07,0x5D,
0x39,0,15,0xB2,0x08,0x27,0x08,0xE1,0x09,0xA1,0x0A,0x03,0x0A,0x32,0x0A,0x61,0x0A,0x61,
0x39,0,19,0xB3,0x00,0x00,0x01,0x6B,0x01,0xB7,0x01,0xE7,0x02,0x16,0x02,0x7F,0x02,0xC9,0x03,0x12,0x03,0x4F,
0x39,0,19,0xB4,0x03,0xC5,0x04,0x1E,0x04,0x75,0x04,0xBC,0x05,0x02,0x05,0x78,0x05,0xEC,0x06,0x50,0x06,0xB3,
0x39,0,15,0xB5,0x07,0x67,0x08,0x11,0x08,0xBD,0x09,0x16,0x09,0x41,0x09,0x71,0x09,0x71,
0x39,0,19,0xB6,0x00,0x00,0x01,0xA5,0x01,0xFF,0x02,0x4A,0x02,0x93,0x03,0x23,0x03,0x87,0x03,0xEA,0x04,0x38,
0x39,0,19,0xB7,0x04,0xD2,0x05,0x3F,0x05,0xAA,0x06,0x00,0x06,0x55,0x06,0xE5,0x07,0x73,0x07,0xEE,0x08,0x68,
0x39,0,15,0xB8,0x09,0x45,0x0A,0x1D,0x0A,0xFF,0x0B,0x76,0x0B,0xB0,0x0B,0xF1,0x0B,0xF1,
0x39,0,2,0xBF,0x1A,
0x39,0,19,0xB0,0x00,0x00,0x01,0xDC,0x02,0x0E,0x02,0x40,0x02,0x71,0x02,0xCF,0x03,0x14,0x03,0x58,0x03,0x91,
0x39,0,19,0xB1,0x04,0x01,0x04,0x54,0x04,0xA6,0x04,0xF0,0x05,0x38,0x05,0xAD,0x06,0x21,0x06,0x83,0x06,0xE4,
0x39,0,15,0xB2,0x07,0x96,0x08,0x3C,0x08,0xD8,0x09,0x28,0x09,0x4E,0x09,0x78,0x09,0x78,
0x39,0,19,0xB3,0x00,0x00,0x01,0xD0,0x01,0xFB,0x02,0x16,0x02,0x2F,0x02,0x78,0x02,0xB9,0x02,0xF8,0x03,0x2E,
0x39,0,19,0xB4,0x03,0x97,0x03,0xE5,0x04,0x31,0x04,0x76,0x04,0xB9,0x05,0x27,0x05,0x94,0x05,0xED,0x06,0x45,
0x39,0,15,0xB5,0x06,0xE7,0x07,0x7B,0x08,0x0D,0x08,0x54,0x08,0x76,0x08,0x9D,0x08,0x9D,
0x39,0,19,0xB6,0x00,0x00,0x01,0xE7,0x02,0x26,0x02,0x5B,0x02,0x8F,0x03,0x02,0x03,0x61,0x03,0xBE,0x04,0x05,
0x39,0,19,0xB7,0x04,0x91,0x04,0xF2,0x05,0x51,0x05,0xA5,0x05,0xF8,0x06,0x7E,0x07,0x02,0x07,0x70,0x07,0xDC,
0x39,0,15,0xB8,0x08,0xA3,0x09,0x5C,0x0A,0x17,0x0A,0x75,0x0A,0xA2,0x0A,0xD2,0x0A,0xD2,
0x39,0,2,0xBF,0x19,
0x39,0,19,0xB0,0x00,0x00,0x01,0xE6,0x02,0x0F,0x02,0x38,0x02,0x61,0x02,0xB9,0x02,0xFA,0x03,0x3B,0x03,0x69,
0x39,0,19,0xB1,0x03,0xD8,0x04,0x30,0x04,0x76,0x04,0xC3,0x05,0x02,0x05,0x75,0x05,0xE0,0x06,0x3F,0x06,0x98,
0x39,0,15,0xB2,0x07,0x3E,0x07,0xD9,0x08,0x6B,0x08,0xB3,0x08,0xD7,0x08,0xF8,0x08,0xF8,
0x39,0,19,0xB3,0x00,0x00,0x01,0xCF,0x01,0xEF,0x02,0x0F,0x02,0x23,0x02,0x62,0x02,0x9E,0x02,0xD9,0x03,0x04,
0x39,0,19,0xB4,0x03,0x6E,0x03,0xC1,0x04,0x08,0x04,0x4B,0x04,0x8A,0x04,0xF3,0x05,0x54,0x05,0xAD,0x05,0xFF,
0x39,0,15,0xB5,0x06,0x97,0x07,0x21,0x07,0xA5,0x07,0xE5,0x08,0x06,0x08,0x24,0x08,0x24,
0x39,0,19,0xB6,0x00,0x00,0x01,0xF0,0x02,0x21,0x02,0x52,0x02,0x7B,0x02,0xE6,0x03,0x3E,0x03,0x93,0x03,0xCD,
0x39,0,19,0xB7,0x04,0x5A,0x04,0xC6,0x05,0x1C,0x05,0x6E,0x05,0xBE,0x06,0x41,0x06,0xB8,0x07,0x24,0x07,0x88,
0x39,0,15,0xB8,0x08,0x41,0x08,0xED,0x09,0x94,0x09,0xE6,0x0A,0x10,0x0A,0x36,0x0A,0x36,
0x39,0,2,0xBF,0x18,
0x39,0,19,0xB0,0x00,0x00,0x01,0xE2,0x02,0x07,0x02,0x2C,0x02,0x51,0x02,0x95,0x02,0xDB,0x03,0x10,0x03,0x46,
0x39,0,19,0xB1,0x03,0xA7,0x03,0xF9,0x04,0x41,0x04,0x81,0x04,0xC2,0x05,0x2C,0x05,0x8F,0x05,0xE9,0x06,0x3E,
0x39,0,15,0xB2,0x06,0xD6,0x07,0x61,0x07,0xE6,0x08,0x24,0x08,0x44,0x08,0x66,0x08,0x66,
0x39,0,19,0xB3,0x00,0x00,0x01,0xBC,0x01,0xE0,0x02,0x04,0x02,0x1B,0x02,0x4B,0x02,0x86,0x02,0xB3,0x02,0xE5,
0x39,0,19,0xB4,0x03,0x41,0x03,0x8D,0x03,0xD2,0x04,0x0E,0x04,0x48,0x04,0xB0,0x05,0x0B,0x05,0x5B,0x05,0xA9,
0x39,0,15,0xB5,0x06,0x37,0x06,0xB7,0x07,0x2E,0x07,0x68,0x07,0x83,0x07,0xA0,0x07,0xA0,
0x39,0,19,0xB6,0x00,0x00,0x01,0xDE,0x02,0x10,0x02,0x42,0x02,0x6C,0x02,0xBF,0x03,0x19,0x03,0x5E,0x03,0xA3,
0x39,0,19,0xB7,0x04,0x1E,0x04,0x83,0x04,0xDC,0x05,0x28,0x05,0x70,0x05,0xEE,0x06,0x5D,0x06,0xBE,0x07,0x1F,
0x39,0,15,0xB8,0x07,0xCA,0x08,0x69,0x08,0xFB,0x09,0x44,0x09,0x68,0x09,0x8C,0x09,0x8C,
0x39,0,2,0xBF,0x17,
0x39,0,19,0xB0,0x00,0x00,0x01,0xDD,0x01,0xFB,0x02,0x19,0x02,0x37,0x02,0x74,0x02,0xAC,0x02,0xE4,0x03,0x0F,
0x39,0,19,0xB1,0x03,0x61,0x03,0xAC,0x03,0xF2,0x04,0x2B,0x04,0x63,0x04,0xC8,0x05,0x21,0x05,0x74,0x05,0xC2,
0x39,0,15,0xB2,0x06,0x4B,0x06,0xC8,0x07,0x3B,0x07,0x74,0x07,0x91,0x07,0xAA,0x07,0xAA,
0x39,0,19,0xB3,0x00,0x00,0x01,0xBE,0x01,0xDC,0x01,0xFA,0x02,0x0D,0x02,0x33,0x02,0x5C,0x02,0x89,0x02,0xB1,
0x39,0,19,0xB4,0x03,0x01,0x03,0x47,0x03,0x86,0x03,0xBE,0x03,0xF3,0x04,0x53,0x04,0xA5,0x04,0xF2,0x05,0x37,
0x39,0,15,0xB5,0x05,0xB6,0x06,0x29,0x06,0x93,0x06,0xC5,0x06,0xDF,0x06,0xF5,0x06,0xF5,
0x39,0,19,0xB6,0x00,0x00,0x01,0xDD,0x02,0x05,0x02,0x2D,0x02,0x4F,0x02,0x96,0x02,0xDB,0x03,0x20,0x03,0x5B,
0x39,0,19,0xB7,0x03,0xC9,0x04,0x29,0x04,0x7C,0x04,0xC4,0x05,0x07,0x05,0x7C,0x05,0xE1,0x06,0x3F,0x06,0x94,
0x39,0,15,0xB8,0x07,0x2C,0x07,0xBA,0x08,0x3B,0x08,0x77,0x08,0x98,0x08,0xB6,0x08,0xB6,
0x39,0,2,0xBF,0x16,
0x39,0,19,0xB0,0x00,0x00,0x01,0xD6,0x01,0xEB,0x02,0x00,0x02,0x15,0x02,0x40,0x02,0x6A,0x02,0x93,0x02,0xBB,
0x39,0,19,0xB1,0x02,0xF7,0x03,0x32,0x03,0x6C,0x03,0x9F,0x03,0xD0,0x04,0x21,0x04,0x70,0x04,0xB3,0x04,0xF5,
0x39,0,15,0xB2,0x05,0x6A,0x05,0xD2,0x06,0x31,0x06,0x5E,0x06,0x73,0x06,0x87,0x06,0x87,
0x39,0,19,0xB3,0x00,0x00,0x01,0xCD,0x01,0xDE,0x01,0xEF,0x01,0xFA,0x02,0x0E,0x02,0x28,0x02,0x48,0x02,0x66,
0x39,0,19,0xB4,0x02,0x9D,0x02,0xD5,0x03,0x0B,0x03,0x39,0x03,0x66,0x03,0xB4,0x04,0x00,0x04,0x3F,0x04,0x7C,
0x39,0,15,0xB5,0x04,0xE6,0x05,0x46,0x05,0x9C,0x05,0xC6,0x05,0xD9,0x05,0xEB,0x05,0xEB,
0x39,0,19,0xB6,0x00,0x00,0x01,0xDF,0x01,0xF9,0x02,0x13,0x02,0x29,0x02,0x54,0x02,0x86,0x02,0xBA,0x02,0xEC,
0x39,0,19,0xB7,0x03,0x3E,0x03,0x8C,0x03,0xD8,0x04,0x16,0x04,0x53,0x04,0xB5,0x05,0x16,0x05,0x63,0x05,0xAF,
0x39,0,15,0xB8,0x06,0x2E,0x06,0xA6,0x07,0x0F,0x07,0x41,0x07,0x58,0x07,0x6E,0x07,0x6E,
0x39,0,2,0xBF,0x15,
0x39,0,19,0xB0,0x00,0x00,0x01,0xC6,0x01,0xDB,0x01,0xF0,0x02,0x05,0x02,0x2C,0x02,0x54,0x02,0x7A,0x02,0xA3,
0x39,0,19,0xB1,0x02,0xF2,0x03,0x2A,0x03,0x66,0x03,0x9A,0x03,0xCC,0x04,0x1D,0x04,0x6C,0x04,0xB0,0x04,0xF3,
0x39,0,15,0xB2,0x05,0x67,0x05,0xCF,0x06,0x2C,0x06,0x59,0x06,0x6F,0x06,0x84,0x06,0x84,
0x39,0,19,0xB3,0x00,0x00,0x01,0xC4,0x01,0xD7,0x01,0xEA,0x01,0xF6,0x02,0x0A,0x02,0x23,0x02,0x3B,0x02,0x5C,
0x39,0,19,0xB4,0x02,0x9B,0x02,0xCE,0x03,0x05,0x03,0x36,0x03,0x65,0x03,0xB1,0x03,0xFB,0x04,0x3A,0x04,0x77,
0x39,0,15,0xB5,0x04,0xE3,0x05,0x42,0x05,0x98,0x05,0xC2,0x05,0xD7,0x05,0xEB,0x05,0xEB,
0x39,0,19,0xB6,0x00,0x00,0x01,0xD7,0x01,0xF2,0x02,0x0D,0x02,0x24,0x02,0x50,0x02,0x7F,0x02,0xAC,0x02,0xDE,
0x39,0,19,0xB7,0x03,0x3F,0x03,0x87,0x03,0xD3,0x04,0x14,0x04,0x52,0x04,0xB3,0x05,0x13,0x05,0x60,0x05,0xAC,
0x39,0,15,0xB8,0x06,0x2E,0x06,0xA3,0x07,0x0B,0x07,0x3D,0x07,0x56,0x07,0x6D,0x07,0x6D,
0x39,0,2,0xBF,0x14,
0x39,0,19,0xB0,0x00,0x00,0x02,0x08,0x02,0x17,0x02,0x26,0x02,0x35,0x02,0x53,0x02,0x75,0x02,0x96,0x02,0xB8,
0x39,0,19,0xB1,0x02,0xFA,0x03,0x31,0x03,0x66,0x03,0x9A,0x03,0xCC,0x04,0x1A,0x04,0x66,0x04,0xA6,0x04,0xE5,
0x39,0,15,0xB2,0x05,0x5C,0x05,0xBE,0x06,0x1D,0x06,0x4A,0x06,0x5F,0x06,0x74,0x06,0x74,
0x39,0,19,0xB3,0x00,0x00,0x02,0x04,0x02,0x11,0x02,0x1E,0x02,0x2B,0x02,0x3C,0x02,0x50,0x02,0x63,0x02,0x7D,
0x39,0,19,0xB4,0x02,0xAE,0x02,0xDD,0x03,0x0B,0x03,0x3A,0x03,0x67,0x03,0xB1,0x03,0xF9,0x04,0x35,0x04,0x6F,
0x39,0,15,0xB5,0x04,0xDB,0x05,0x36,0x05,0x8D,0x05,0xB5,0x05,0xC8,0x05,0xDA,0x05,0xDA,
0x39,0,19,0xB6,0x00,0x00,0x02,0x22,0x02,0x35,0x02,0x48,0x02,0x5B,0x02,0x7B,0x02,0xA3,0x02,0xCA,0x02,0xF4,
0x39,0,19,0xB7,0x03,0x46,0x03,0x8D,0x03,0xD2,0x04,0x11,0x04,0x4F,0x04,0xAE,0x05,0x0B,0x05,0x54,0x05,0x9C,
0x39,0,15,0xB8,0x06,0x22,0x06,0x91,0x06,0xFB,0x07,0x2D,0x07,0x44,0x07,0x5A,0x07,0x5A,
0x39,0,2,0xBF,0x13,
0x39,0,19,0xB0,0x00,0x00,0x02,0x69,0x02,0x71,0x02,0x79,0x02,0x81,0x02,0x92,0x02,0xA3,0x02,0xBD,0x02,0xD6,
0x39,0,19,0xB1,0x03,0x0A,0x03,0x3D,0x03,0x6F,0x03,0x9E,0x03,0xCC,0x04,0x15,0x04,0x5C,0x04,0x9E,0x04,0xDE,
0x39,0,15,0xB2,0x05,0x4D,0x05,0xAE,0x06,0x06,0x06,0x31,0x06,0x45,0x06,0x58,0x06,0x58,
0x39,0,19,0xB3,0x00,0x00,0x02,0x61,0x02,0x69,0x02,0x71,0x02,0x79,0x02,0x89,0x02,0x93,0x02,0xA3,0x02,0xB2,
0x39,0,19,0xB4,0x02,0xD6,0x02,0xFD,0x03,0x23,0x03,0x4C,0x03,0x74,0x03,0xB4,0x03,0xF2,0x04,0x2E,0x04,0x69,
0x39,0,15,0xB5,0x04,0xCF,0x05,0x28,0x05,0x79,0x05,0xA1,0x05,0xB3,0x05,0xC4,0x05,0xC4,
0x39,0,19,0xB6,0x00,0x00,0x02,0x81,0x02,0x8E,0x02,0x9B,0x02,0xA8,0x02,0xC2,0x02,0xD8,0x02,0xF8,0x03,0x17,
0x39,0,19,0xB7,0x03,0x58,0x03,0x9A,0x03,0xDA,0x04,0x14,0x04,0x4D,0x04,0xA3,0x04,0xF8,0x05,0x45,0x05,0x91,
0x39,0,15,0xB8,0x06,0x11,0x06,0x7F,0x06,0xE2,0x07,0x12,0x07,0x28,0x07,0x3D,0x07,0x3D,
0x39,0,2,0xBF,0x12,
0x39,0,19,0xB0,0x00,0x00,0x02,0xA6,0x02,0xAE,0x02,0xB6,0x02,0xBE,0x02,0xCE,0x02,0xDE,0x02,0xEE,0x02,0xFC,
0x39,0,19,0xB1,0x03,0x27,0x03,0x4F,0x03,0x76,0x03,0xA1,0x03,0xCA,0x04,0x0E,0x04,0x51,0x04,0x8B,0x04,0xC3,
0x39,0,15,0xB2,0x05,0x2C,0x05,0x8B,0x05,0xE0,0x06,0x08,0x06,0x1B,0x06,0x2F,0x06,0x2F,
0x39,0,19,0xB3,0x00,0x00,0x02,0xA4,0x02,0xAD,0x02,0xB6,0x02,0xBF,0x02,0xD2,0x02,0xDE,0x02,0xE8,0x02,0xF0,
0x39,0,19,0xB4,0x03,0x0B,0x03,0x27,0x03,0x41,0x03,0x62,0x03,0x82,0x03,0xBC,0x03,0xF5,0x04,0x2A,0x04,0x5D,
0x39,0,15,0xB5,0x04,0xBB,0x05,0x0D,0x05,0x5B,0x05,0x7F,0x05,0x90,0x05,0xA0,0x05,0xA0,
0x39,0,19,0xB6,0x00,0x00,0x02,0xD6,0x02,0xE0,0x02,0xEA,0x02,0xF4,0x03,0x09,0x03,0x1B,0x03,0x30,0x03,0x44,
0x39,0,19,0xB7,0x03,0x78,0x03,0xAA,0x03,0xDA,0x04,0x0F,0x04,0x43,0x04,0x97,0x04,0xEA,0x05,0x30,0x05,0x74,
0x39,0,15,0xB8,0x05,0xEE,0x06,0x55,0x06,0xB7,0x06,0xE5,0x06,0xFA,0x07,0x0F,0x07,0x0F,
0x39,0,2,0xBF,0x11,
0x39,0,19,0xB0,0x00,0x00,0x02,0xE1,0x02,0xE8,0x02,0xEF,0x02,0xF6,0x03,0x04,0x03,0x12,0x03,0x20,0x03,0x27,
0x39,0,19,0xB1,0x03,0x43,0x03,0x61,0x03,0x7E,0x03,0x9F,0x03,0xBF,0x03,0xFC,0x04,0x37,0x04,0x6D,0x04,0xA1,
0x39,0,15,0xB2,0x05,0x01,0x05,0x57,0x05,0xA6,0x05,0xCC,0x05,0xDE,0x05,0xF0,0x05,0xF0,
0x39,0,19,0xB3,0x00,0x00,0x02,0xEE,0x02,0xF5,0x02,0xFC,0x03,0x03,0x03,0x11,0x03,0x1F,0x03,0x28,0x03,0x2F,
0x39,0,19,0xB4,0x03,0x41,0x03,0x55,0x03,0x67,0x03,0x7F,0x03,0x96,0x03,0xC5,0x03,0xF3,0x04,0x20,0x04,0x4B,
0x39,0,15,0xB5,0x04,0x9B,0x04,0xE7,0x05,0x2D,0x05,0x4F,0x05,0x5E,0x05,0x6D,0x05,0x6D,
0x39,0,19,0xB6,0x00,0x00,0x03,0x28,0x03,0x2F,0x03,0x36,0x03,0x3D,0x03,0x4B,0x03,0x59,0x03,0x65,0x03,0x72,
0x39,0,19,0xB7,0x03,0x96,0x03,0xBB,0x03,0xDE,0x04,0x09,0x04,0x32,0x04,0x7E,0x04,0xC9,0x05,0x0A,0x05,0x49,
0x39,0,15,0xB8,0x05,0xB7,0x06,0x1C,0x06,0x75,0x06,0xA1,0x06,0xB5,0x06,0xC8,0x06,0xC8,
0x39,0,2,0xBF,0x10,
0x39,0,19,0xB0,0x00,0x00,0x03,0x20,0x03,0x25,0x03,0x2A,0x03,0x2F,0x03,0x3A,0x03,0x45,0x03,0x50,0x03,0x5B,
0x39,0,19,0xB1,0x03,0x71,0x03,0x7C,0x03,0x8C,0x03,0x9E,0x03,0xB6,0x03,0xDE,0x04,0x06,0x04,0x30,0x04,0x59,
0x39,0,15,0xB2,0x04,0xA3,0x04,0xEA,0x05,0x2C,0x05,0x4C,0x05,0x5B,0x05,0x6B,0x05,0x6B,
0x39,0,19,0xB3,0x00,0x00,0x03,0x2F,0x03,0x35,0x03,0x3B,0x03,0x41,0x03,0x4E,0x03,0x5B,0x03,0x68,0x03,0x75,
0x39,0,19,0xB4,0x03,0x86,0x03,0x8C,0x03,0x95,0x03,0xA1,0x03,0xAF,0x03,0xCC,0x03,0xE9,0x04,0x08,0x04,0x26,
0x39,0,15,0xB5,0x04,0x60,0x04,0x99,0x04,0xD0,0x04,0xEB,0x04,0xF7,0x05,0x03,0x05,0x03,
0x39,0,19,0xB6,0x00,0x00,0x03,0x5F,0x03,0x66,0x03,0x6D,0x03,0x74,0x03,0x82,0x03,0x90,0x03,0x9E,0x03,0xAC,
0x39,0,19,0xB7,0x03,0xC4,0x03,0xD2,0x03,0xE7,0x03,0xFE,0x04,0x19,0x04,0x4E,0x04,0x82,0x04,0xB5,0x04,0xE7,
0x39,0,15,0xB8,0x05,0x42,0x05,0x96,0x05,0xE4,0x06,0x0A,0x06,0x1B,0x06,0x2E,0x06,0x2E,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xBF,0x2B,
0x39,0,19,0xB0,0x00,0x00,0x01,0x6D,0x01,0xC3,0x02,0x19,0x02,0x6E,0x02,0xEB,0x03,0x41,0x03,0x96,0x03,0xD8,
0x39,0,19,0xB1,0x04,0x58,0x04,0xBB,0x05,0x1D,0x05,0x6C,0x05,0xBA,0x06,0x3D,0x06,0xBE,0x07,0x2C,0x07,0x99,
0x39,0,15,0xB2,0x08,0x4E,0x08,0xF1,0x09,0xA1,0x09,0xFC,0x0A,0x28,0x0A,0x50,0x0A,0x50,
0x39,0,19,0xB3,0x00,0x00,0x00,0xDC,0x01,0x5D,0x01,0xAE,0x01,0xFE,0x02,0x81,0x02,0xD9,0x03,0x2F,0x03,0x6E,
0x39,0,19,0xB4,0x03,0xE8,0x04,0x46,0x04,0xA2,0x04,0xF1,0x05,0x3F,0x05,0xB6,0x06,0x2C,0x06,0x94,0x06,0xFB,
0x39,0,15,0xB5,0x07,0xA0,0x08,0x33,0x08,0xD5,0x09,0x28,0x09,0x50,0x09,0x7A,0x09,0x7A,
0x39,0,19,0xB6,0x00,0x00,0x01,0x4E,0x01,0xC7,0x02,0x2C,0x02,0x90,0x03,0x33,0x03,0xA5,0x04,0x15,0x04,0x63,
0x39,0,19,0xB7,0x04,0xFD,0x05,0x6F,0x05,0xE0,0x06,0x3D,0x06,0x99,0x07,0x29,0x07,0xB8,0x08,0x36,0x08,0xB2,
0x39,0,15,0xB8,0x09,0x88,0x0A,0x4A,0x0B,0x1E,0x0B,0x90,0x0B,0xC7,0x0B,0xFE,0x0B,0xFE,
0x39,0,2,0xBF,0x2A,
0x39,0,19,0xB0,0x00,0x00,0x01,0x8A,0x01,0xD0,0x02,0x16,0x02,0x5B,0x02,0xCE,0x03,0x1E,0x03,0x6D,0x03,0xAA,
0x39,0,19,0xB1,0x04,0x22,0x04,0x7C,0x04,0xD5,0x05,0x21,0x05,0x6C,0x05,0xE4,0x06,0x5A,0x06,0xC1,0x07,0x26,
0x39,0,15,0xB2,0x07,0xD3,0x08,0x60,0x08,0xEC,0x09,0x37,0x09,0x5B,0x09,0x81,0x09,0x81,
0x39,0,19,0xB3,0x00,0x00,0x01,0x2D,0x01,0x88,0x01,0xC1,0x01,0xF9,0x02,0x69,0x02,0xB8,0x03,0x06,0x03,0x42,
0x39,0,19,0xB4,0x03,0xB8,0x04,0x0E,0x04,0x63,0x04,0xAB,0x04,0xF2,0x05,0x62,0x05,0xD0,0x06,0x30,0x06,0x8E,
0x39,0,15,0xB5,0x07,0x30,0x07,0xB2,0x08,0x30,0x08,0x74,0x08,0x95,0x08,0xB9,0x08,0xB9,
0x39,0,19,0xB6,0x00,0x00,0x01,0x6A,0x01,0xCD,0x02,0x20,0x02,0x71,0x03,0x09,0x03,0x72,0x03,0xDA,0x04,0x26,
0x39,0,19,0xB7,0x04,0xBC,0x05,0x26,0x05,0x8F,0x05,0xE5,0x06,0x3A,0x06,0xC2,0x07,0x48,0x07,0xBB,0x08,0x2D,
0x39,0,15,0xB8,0x08,0xF8,0x09,0xA0,0x0A,0x43,0x0A,0x9C,0x0A,0xC7,0x0A,0xF7,0x0A,0xF7,
0x39,0,2,0xBF,0x29,
0x39,0,19,0xB0,0x00,0x00,0x01,0x98,0x01,0xD5,0x02,0x12,0x02,0x4F,0x02,0xB6,0x03,0x05,0x03,0x4F,0x03,0x8C,
0x39,0,19,0xB1,0x03,0xF7,0x04,0x4E,0x04,0xA2,0x04,0xED,0x05,0x36,0x05,0xAF,0x06,0x12,0x06,0x7C,0x06,0xD6,
0x39,0,15,0xB2,0x07,0x7F,0x08,0x10,0x08,0x8A,0x08,0xC7,0x08,0xE7,0x09,0x05,0x09,0x05,
0x39,0,19,0xB3,0x00,0x00,0x01,0x37,0x01,0x7B,0x01,0xBF,0x01,0xEA,0x02,0x4B,0x02,0xA0,0x02,0xE6,0x03,0x25,
0x39,0,19,0xB4,0x03,0x8E,0x03,0xE6,0x04,0x34,0x04,0x7C,0x04,0xBE,0x05,0x2D,0x05,0x8E,0x05,0xEF,0x06,0x45,
0x39,0,15,0xB5,0x06,0xE1,0x07,0x68,0x07,0xD7,0x08,0x0F,0x08,0x2C,0x08,0x49,0x08,0x49,
0x39,0,19,0xB6,0x00,0x00,0x01,0x7D,0x01,0xCC,0x02,0x1B,0x02,0x5D,0x02,0xE2,0x03,0x53,0x03,0xB3,0x04,0x02,
0x39,0,19,0xB7,0x04,0x88,0x04,0xF4,0x05,0x55,0x05,0xAB,0x05,0xFC,0x06,0x87,0x06,0xFC,0x07,0x69,0x07,0xD2,
0x39,0,15,0xB8,0x08,0x95,0x09,0x3C,0x09,0xCF,0x0A,0x17,0x0A,0x3F,0x0A,0x65,0x0A,0x65,
0x39,0,2,0xBF,0x28,
0x39,0,19,0xB0,0x00,0x00,0x01,0x81,0x01,0xBE,0x01,0xFB,0x02,0x38,0x02,0x8D,0x02,0xDD,0x03,0x19,0x03,0x5B,
0x39,0,19,0xB1,0x03,0xC1,0x04,0x13,0x04,0x65,0x04,0xAB,0x04,0xEB,0x05,0x5B,0x05,0xC2,0x06,0x20,0x06,0x77,
0x39,0,15,0xB2,0x07,0x10,0x07,0xA1,0x08,0x1C,0x08,0x50,0x08,0x6C,0x08,0x86,0x08,0x86,
0x39,0,19,0xB3,0x00,0x00,0x01,0x15,0x01,0x5E,0x01,0xA7,0x01,0xD5,0x02,0x27,0x02,0x79,0x02,0xB6,0x02,0xF2,
0x39,0,19,0xB4,0x03,0x58,0x03,0xAB,0x03,0xF5,0x04,0x39,0x04,0x76,0x04,0xE3,0x05,0x42,0x05,0x97,0x05,0xE8,
0x39,0,15,0xB5,0x06,0x7A,0x07,0x01,0x07,0x73,0x07,0xA2,0x07,0xBB,0x07,0xD3,0x07,0xD3,
0x39,0,19,0xB6,0x00,0x00,0x01,0x52,0x01,0xA6,0x01,0xFA,0x02,0x40,0x02,0xAE,0x03,0x1D,0x03,0x71,0x03,0xC1,
0x39,0,19,0xB7,0x04,0x47,0x04,0xAE,0x05,0x0B,0x05,0x5E,0x05,0xA9,0x06,0x2A,0x06,0x9F,0x07,0x02,0x07,0x67,
0x39,0,15,0xB8,0x08,0x16,0x08,0xBB,0x09,0x4A,0x09,0x88,0x09,0xA9,0x09,0xC7,0x09,0xC7,
0x39,0,2,0xBF,0x27,
0x39,0,19,0xB0,0x00,0x00,0x01,0x9D,0x01,0xC4,0x01,0xEB,0x02,0x12,0x02,0x6F,0x02,0xA8,0x02,0xDF,0x03,0x18,
0x39,0,19,0xB1,0x03,0x72,0x03,0xC2,0x04,0x0B,0x04,0x4C,0x04,0x87,0x04,0xF1,0x05,0x4E,0x05,0xA3,0x05,0xF3,
0x39,0,15,0xB2,0x06,0x82,0x07,0x02,0x07,0x7A,0x07,0xB1,0x07,0xCB,0x07,0xE5,0x07,0xE5,
0x39,0,19,0xB3,0x00,0x00,0x01,0x4C,0x01,0x74,0x01,0x9C,0x01,0xB5,0x02,0x02,0x02,0x45,0x02,0x7E,0x02,0xB4,
0x39,0,19,0xB4,0x03,0x0D,0x03,0x5C,0x03,0xA3,0x03,0xE2,0x04,0x1B,0x04,0x80,0x04,0xD8,0x05,0x2A,0x05,0x71,
0x39,0,15,0xB5,0x05,0xF5,0x06,0x6E,0x06,0xDB,0x07,0x10,0x07,0x28,0x07,0x40,0x07,0x40,
0x39,0,19,0xB6,0x00,0x00,0x01,0x81,0x01,0xB4,0x01,0xE7,0x02,0x12,0x02,0x7E,0x02,0xD9,0x03,0x22,0x03,0x6C,
0x39,0,19,0xB7,0x03,0xE3,0x04,0x49,0x04,0xA1,0x04,0xF0,0x05,0x36,0x05,0xB2,0x06,0x1C,0x06,0x7E,0x06,0xD9,
0x39,0,15,0xB8,0x07,0x75,0x08,0x06,0x08,0x8C,0x08,0xCD,0x08,0xEB,0x09,0x0B,0x09,0x0B,
0x39,0,2,0xBF,0x26,
0x39,0,19,0xB0,0x00,0x00,0x01,0x94,0x01,0xAD,0x01,0xC6,0x01,0xDF,0x02,0x1B,0x02,0x50,0x02,0x82,0x02,0xB3,
0x39,0,19,0xB1,0x03,0x03,0x03,0x46,0x03,0x87,0x03,0xBE,0x03,0xF3,0x04,0x47,0x04,0x9A,0x04,0xE0,0x05,0x25,
0x39,0,15,0xB2,0x05,0x9C,0x06,0x06,0x06,0x67,0x06,0x95,0x06,0xAA,0x06,0xBF,0x06,0xBF,
0x39,0,19,0xB3,0x00,0x00,0x01,0x51,0x01,0x6A,0x01,0x83,0x01,0x93,0x01,0xC0,0x01,0xEF,0x02,0x1F,0x02,0x4E,
0x39,0,19,0xB4,0x02,0x9E,0x02,0xDF,0x03,0x1F,0x03,0x54,0x03,0x87,0x03,0xD9,0x04,0x29,0x04,0x6D,0x04,0xB0,
0x39,0,15,0xB5,0x05,0x21,0x05,0x82,0x05,0xDC,0x06,0x07,0x06,0x1B,0x06,0x2E,0x06,0x2E,
0x39,0,19,0xB6,0x00,0x00,0x01,0x84,0x01,0xA2,0x01,0xC0,0x01,0xD9,0x02,0x21,0x02,0x62,0x02,0xA4,0x02,0xE4,
0x39,0,19,0xB7,0x03,0x4F,0x03,0xA5,0x03,0xFA,0x04,0x3E,0x04,0x80,0x04,0xE5,0x05,0x49,0x05,0x9A,0x05,0xEA,
0x39,0,15,0xB8,0x06,0x74,0x06,0xED,0x07,0x58,0x07,0x8C,0x07,0xA4,0x07,0xBC,0x07,0xBC,
0x39,0,2,0xBF,0x25,
0x39,0,19,0xB0,0x00,0x00,0x01,0x46,0x01,0x66,0x01,0x86,0x01,0xA6,0x01,0xE3,0x02,0x23,0x02,0x61,0x02,0x91,
0x39,0,19,0xB1,0x02,0xEE,0x03,0x37,0x03,0x75,0x03,0xAF,0x03,0xE5,0x04,0x3C,0x04,0x92,0x04,0xDA,0x05,0x21,
0x39,0,15,0xB2,0x05,0x98,0x06,0x04,0x06,0x62,0x06,0x8F,0x06,0xA6,0x06,0xBE,0x06,0xBE,
0x39,0,19,0xB3,0x00,0x00,0x01,0x48,0x01,0x66,0x01,0x84,0x01,0x97,0x01,0xB9,0x01,0xE9,0x02,0x17,0x02,0x40,
0x39,0,19,0xB4,0x02,0x8F,0x02,0xD4,0x03,0x0C,0x03,0x46,0x03,0x7C,0x03,0xCF,0x04,0x21,0x04,0x65,0x04,0xA8,
0x39,0,15,0xB5,0x05,0x19,0x05,0x7D,0x05,0xD7,0x06,0x02,0x06,0x16,0x06,0x2B,0x06,0x2B,
0x39,0,19,0xB6,0x00,0x00,0x01,0x62,0x01,0x89,0x01,0xB0,0x01,0xD1,0x02,0x11,0x02,0x58,0x02,0x9E,0x02,0xD6,
0x39,0,19,0xB7,0x03,0x44,0x03,0x9F,0x03,0xEB,0x04,0x32,0x04,0x74,0x04,0xDB,0x05,0x40,0x05,0x93,0x05,0xE5,
0x39,0,15,0xB8,0x06,0x6E,0x06,0xE9,0x07,0x53,0x07,0x87,0x07,0x9E,0x07,0xB8,0x07,0xB8,
0x39,0,2,0xBF,0x24,
0x39,0,19,0xB0,0x00,0x00,0x01,0x9A,0x01,0xAE,0x01,0xC2,0x01,0xD6,0x01,0xFF,0x02,0x30,0x02,0x60,0x02,0x90,
0x39,0,19,0xB1,0x02,0xED,0x03,0x31,0x03,0x73,0x03,0xAA,0x03,0xE0,0x04,0x38,0x04,0x8E,0x04,0xD4,0x05,0x18,
0x39,0,15,0xB2,0x05,0x90,0x05,0xF8,0x06,0x57,0x06,0x85,0x06,0x9B,0x06,0xAB,0x06,0xAB,
0x39,0,19,0xB3,0x00,0x00,0x01,0x60,0x01,0x79,0x01,0x92,0x01,0xAB,0x01,0xCB,0x01,0xED,0x02,0x0E,0x02,0x38,
0x39,0,19,0xB4,0x02,0x8A,0x02,0xCC,0x03,0x0D,0x03,0x42,0x03,0x75,0x03,0xCB,0x04,0x1F,0x04,0x61,0x04,0xA2,
0x39,0,15,0xB5,0x05,0x10,0x05,0x72,0x05,0xCA,0x05,0xF8,0x06,0x0D,0x06,0x1C,0x06,0x1C,
0x39,0,19,0xB6,0x00,0x00,0x01,0x76,0x01,0x9D,0x01,0xC4,0x01,0xEB,0x02,0x2C,0x02,0x63,0x02,0x99,0x02,0xD1,
0x39,0,19,0xB7,0x03,0x3E,0x03,0x94,0x03,0xE9,0x04,0x2C,0x04,0x6E,0x04,0xD7,0x05,0x3E,0x05,0x8E,0x05,0xDC,
0x39,0,15,0xB8,0x06,0x62,0x06,0xD8,0x07,0x44,0x07,0x78,0x07,0x90,0x07,0xA6,0x07,0xA6,
0x39,0,2,0xBF,0x23,
0x39,0,19,0xB0,0x00,0x00,0x01,0xE2,0x01,0xF1,0x02,0x00,0x02,0x0F,0x02,0x2D,0x02,0x4B,0x02,0x71,0x02,0x96,
0x39,0,19,0xB1,0x02,0xE7,0x03,0x28,0x03,0x68,0x03,0x9E,0x03,0xD3,0x04,0x28,0x04,0x7C,0x04,0xC2,0x05,0x06,
0x39,0,15,0xB2,0x05,0x79,0x05,0xDD,0x06,0x3A,0x06,0x5D,0x06,0x6D,0x06,0x8E,0x06,0x8E,
0x39,0,19,0xB3,0x00,0x00,0x01,0xB1,0x01,0xC0,0x01,0xCF,0x01,0xDE,0x01,0xFC,0x02,0x0F,0x02,0x2E,0x02,0x4C,
0x39,0,19,0xB4,0x02,0x8F,0x02,0xCC,0x03,0x07,0x03,0x3A,0x03,0x6C,0x03,0xBE,0x04,0x0F,0x04,0x51,0x04,0x91,
0x39,0,15,0xB5,0x04,0xFF,0x05,0x5E,0x05,0xB3,0x05,0xD4,0x05,0xE3,0x06,0x02,0x06,0x02,
0x39,0,19,0xB6,0x00,0x00,0x01,0xDB,0x01,0xF2,0x02,0x09,0x02,0x20,0x02,0x4E,0x02,0x75,0x02,0xA7,0x02,0xD7,
0x39,0,19,0xB7,0x03,0x3A,0x03,0x8C,0x03,0xDD,0x04,0x1F,0x04,0x60,0x04,0xC4,0x05,0x27,0x05,0x77,0x05,0xC6,
0x39,0,15,0xB8,0x06,0x4B,0x06,0xBE,0x07,0x28,0x07,0x52,0x07,0x65,0x07,0x88,0x07,0x88,
0x39,0,2,0xBF,0x22,
0x39,0,19,0xB0,0x00,0x00,0x02,0x1A,0x02,0x25,0x02,0x30,0x02,0x3B,0x02,0x51,0x02,0x67,0x02,0x82,0x02,0x9C,
0x39,0,19,0xB1,0x02,0xDB,0x03,0x19,0x03,0x55,0x03,0x89,0x03,0xBC,0x04,0x10,0x04,0x62,0x04,0xA5,0x04,0xE6,
0x39,0,15,0xB2,0x05,0x58,0x05,0xB6,0x06,0x10,0x06,0x3A,0x06,0x4E,0x06,0x6E,0x06,0x6E,
0x39,0,19,0xB3,0x00,0x00,0x01,0xD5,0x01,0xE5,0x01,0xF5,0x02,0x05,0x02,0x26,0x02,0x3B,0x02,0x51,0x02,0x65,
0x39,0,19,0xB4,0x02,0x9A,0x02,0xCD,0x02,0xFE,0x03,0x2F,0x03,0x5E,0x03,0xAE,0x03,0xFD,0x04,0x3B,0x04,0x78,
0x39,0,15,0xB5,0x04,0xDE,0x05,0x3A,0x05,0x8E,0x05,0xB6,0x05,0xC8,0x05,0xDF,0x05,0xDF,
0x39,0,19,0xB6,0x00,0x00,0x02,0x2C,0x02,0x3A,0x02,0x48,0x02,0x56,0x02,0x72,0x02,0x8A,0x02,0xB3,0x02,0xDA,
0x39,0,19,0xB7,0x03,0x31,0x03,0x7C,0x03,0xC6,0x04,0x06,0x04,0x44,0x04,0xA8,0x05,0x0B,0x05,0x59,0x05,0xA5,
0x39,0,15,0xB8,0x06,0x26,0x06,0x93,0x06,0xF9,0x07,0x29,0x07,0x40,0x07,0x55,0x07,0x55,
0x39,0,2,0xBF,0x21,
0x39,0,19,0xB0,0x00,0x00,0x02,0x72,0x02,0x76,0x02,0x7A,0x02,0x7E,0x02,0x86,0x02,0x8E,0x02,0x96,0x02,0xB1,
0x39,0,19,0xB1,0x02,0xDD,0x03,0x0C,0x03,0x39,0x03,0x69,0x03,0x97,0x03,0xE8,0x04,0x37,0x04,0x76,0x04,0xB3,
0x39,0,15,0xB2,0x05,0x1D,0x05,0x7A,0x05,0xCF,0x05,0xF8,0x06,0x0B,0x06,0x1F,0x06,0x1F,
0x39,0,19,0xB3,0x00,0x00,0x01,0xE6,0x01,0xF6,0x02,0x06,0x02,0x16,0x02,0x36,0x02,0x56,0x02,0x6A,0x02,0x80,
0x39,0,19,0xB4,0x02,0xA5,0x02,0xCC,0x02,0xF1,0x03,0x1B,0x03,0x44,0x03,0x8F,0x03,0xD9,0x04,0x14,0x04,0x4E,
0x39,0,15,0xB5,0x04,0xAE,0x05,0x07,0x05,0x54,0x05,0x7A,0x05,0x8C,0x05,0x9C,0x05,0x9C,
0x39,0,19,0xB6,0x00,0x00,0x02,0x52,0x02,0x5F,0x02,0x6C,0x02,0x79,0x02,0x93,0x02,0xAD,0x02,0xC3,0x02,0xE7,
0x39,0,19,0xB7,0x03,0x26,0x03,0x65,0x03,0xA2,0x03,0xDE,0x04,0x18,0x04,0x77,0x04,0xD5,0x05,0x20,0x05,0x6A,
0x39,0,15,0xB8,0x05,0xE3,0x06,0x50,0x06,0xAF,0x06,0xDE,0x06,0xF4,0x07,0x08,0x07,0x08,
0x39,0,2,0xBF,0x20,
0x39,0,19,0xB0,0x00,0x00,0x02,0x94,0x02,0x99,0x02,0x9E,0x02,0xA3,0x02,0xAD,0x02,0xB7,0x02,0xC1,0x02,0xCB,
0x39,0,19,0xB1,0x02,0xDF,0x02,0xFD,0x03,0x17,0x03,0x37,0x03,0x59,0x03,0x99,0x03,0xD9,0x04,0x11,0x04,0x48,
0x39,0,15,0xB2,0x04,0xA5,0x04,0xFA,0x05,0x46,0x05,0x69,0x05,0x79,0x05,0x89,0x05,0x89,
0x39,0,19,0xB3,0x00,0x00,0x02,0x06,0x02,0x12,0x02,0x1E,0x02,0x2A,0x02,0x42,0x02,0x5A,0x02,0x72,0x02,0x8A,
0x39,0,19,0xB4,0x02,0xA8,0x02,0xC3,0x02,0xDA,0x02,0xF6,0x03,0x12,0x03,0x4D,0x03,0x89,0x03,0xC0,0x03,0xF5,
0x39,0,15,0xB5,0x04,0x4C,0x04,0x98,0x04,0xDC,0x04,0xFC,0x05,0x0B,0x05,0x19,0x05,0x19,
0x39,0,19,0xB6,0x00,0x00,0x02,0x6F,0x02,0x7A,0x02,0x85,0x02,0x90,0x02,0xA6,0x02,0xBC,0x02,0xD2,0x02,0xE8,
0x39,0,19,0xB7,0x03,0x0D,0x03,0x3C,0x03,0x64,0x03,0x94,0x03,0xC3,0x04,0x15,0x04,0x64,0x04,0xA7,0x04,0xE9,
0x39,0,15,0xB8,0x05,0x5B,0x05,0xBD,0x06,0x11,0x06,0x39,0x06,0x4C,0x06,0x60,0x06,0x60,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xBF,0x3B,
0x39,0,19,0xB0,0x00,0x00,0x01,0xAA,0x01,0xF2,0x02,0x3A,0x02,0x81,0x02,0xF3,0x03,0x47,0x03,0x9A,0x03,0xD8,
0x39,0,19,0xB1,0x04,0x51,0x04,0xB4,0x05,0x15,0x05,0x66,0x05,0xB5,0x06,0x36,0x06,0xB5,0x07,0x23,0x07,0x8F,
0x39,0,15,0xB2,0x08,0x42,0x08,0xE4,0x09,0x91,0x09,0xEC,0x0A,0x18,0x0A,0x46,0x0A,0x46,
0x39,0,19,0xB3,0x00,0x00,0x01,0x62,0x01,0xBD,0x01,0xF6,0x02,0x2E,0x02,0x95,0x02,0xE8,0x03,0x3A,0x03,0x75,
0x39,0,19,0xB4,0x03,0xE9,0x04,0x45,0x04,0xA0,0x04,0xEC,0x05,0x36,0x05,0xB0,0x06,0x28,0x06,0x8D,0x06,0xF1,
0x39,0,15,0xB5,0x07,0x96,0x08,0x26,0x08,0xC6,0x09,0x18,0x09,0x40,0x09,0x6D,0x09,0x6D,
0x39,0,19,0xB6,0x00,0x00,0x01,0xAD,0x02,0x0E,0x02,0x5F,0x02,0xAF,0x03,0x3C,0x03,0xAB,0x04,0x18,0x04,0x63,
0x39,0,19,0xB7,0x04,0xF7,0x05,0x68,0x05,0xD8,0x06,0x34,0x06,0x8E,0x07,0x23,0x07,0xB6,0x08,0x31,0x08,0xAA,
0x39,0,15,0xB8,0x09,0x7E,0x0A,0x3C,0x0B,0x10,0x0B,0x7F,0x0B,0xB5,0x0B,0xF1,0x0B,0xF1,
0x39,0,2,0xBF,0x3A,
0x39,0,19,0xB0,0x00,0x00,0x01,0xEE,0x02,0x22,0x02,0x56,0x02,0x89,0x02,0xDD,0x03,0x2B,0x03,0x77,0x03,0xB1,
0x39,0,19,0xB1,0x04,0x21,0x04,0x79,0x04,0xD0,0x05,0x1A,0x05,0x62,0x05,0xDC,0x06,0x54,0x06,0xB8,0x07,0x1A,
0x39,0,15,0xB2,0x07,0xC6,0x08,0x54,0x08,0xDD,0x09,0x29,0x09,0x4D,0x09,0x73,0x09,0x73,
0x39,0,19,0xB3,0x00,0x00,0x01,0xDF,0x02,0x0B,0x02,0x27,0x02,0x42,0x02,0x88,0x02,0xCE,0x03,0x12,0x03,0x4A,
0x39,0,19,0xB4,0x03,0xB8,0x04,0x0C,0x04,0x5F,0x04,0xA4,0x04,0xE8,0x05,0x5A,0x05,0xCA,0x06,0x27,0x06,0x82,
0x39,0,15,0xB5,0x07,0x25,0x07,0xA9,0x08,0x22,0x08,0x67,0x08,0x88,0x08,0xAA,0x08,0xAA,
0x39,0,19,0xB6,0x00,0x00,0x01,0xFB,0x02,0x3D,0x02,0x74,0x02,0xA9,0x03,0x17,0x03,0x7C,0x03,0xDF,0x04,0x28,
0x39,0,19,0xB7,0x04,0xB7,0x05,0x1E,0x05,0x84,0x05,0xDA,0x06,0x2E,0x06,0xB7,0x07,0x3F,0x07,0xB0,0x08,0x20,
0x39,0,15,0xB8,0x08,0xEB,0x09,0x93,0x0A,0x32,0x0A,0x8C,0x0A,0xB8,0x0A,0xE5,0x0A,0xE5,
0x39,0,2,0xBF,0x39,
0x39,0,19,0xB0,0x00,0x00,0x01,0xF7,0x02,0x22,0x02,0x4D,0x02,0x78,0x02,0xCE,0x03,0x16,0x03,0x55,0x03,0x8F,
0x39,0,19,0xB1,0x03,0xF5,0x04,0x52,0x04,0xA2,0x04,0xEA,0x05,0x31,0x05,0xA9,0x06,0x10,0x06,0x75,0x06,0xC9,
0x39,0,15,0xB2,0x07,0x74,0x08,0x07,0x08,0x7C,0x08,0xB7,0x08,0xD8,0x08,0xF7,0x08,0xF7,
0x39,0,19,0xB3,0x00,0x00,0x01,0xC6,0x01,0xF1,0x02,0x1C,0x02,0x37,0x02,0x7B,0x02,0xBB,0x02,0xF6,0x03,0x2D,
0x39,0,19,0xB4,0x03,0x90,0x03,0xE7,0x04,0x37,0x04,0x7B,0x04,0xB9,0x05,0x29,0x05,0x8B,0x05,0xE5,0x06,0x39,
0x39,0,15,0xB5,0x06,0xD6,0x07,0x5F,0x07,0xCB,0x07,0xFF,0x08,0x1F,0x08,0x3C,0x08,0x3C,
0x39,0,19,0xB6,0x00,0x00,0x01,0xF0,0x02,0x2A,0x02,0x64,0x02,0x95,0x03,0x04,0x03,0x5F,0x03,0xB7,0x04,0x01,
0x39,0,19,0xB7,0x04,0x80,0x04,0xF1,0x05,0x52,0x05,0xA6,0x05,0xF4,0x06,0x7E,0x06,0xF1,0x07,0x62,0x07,0xC5,
0x39,0,15,0xB8,0x08,0x86,0x09,0x32,0x09,0xC2,0x0A,0x09,0x0A,0x31,0x0A,0x56,0x0A,0x56,
0x39,0,2,0xBF,0x38,
0x39,0,19,0xB0,0x00,0x00,0x01,0xF0,0x02,0x15,0x02,0x3A,0x02,0x5F,0x02,0xAE,0x02,0xF2,0x03,0x2A,0x03,0x64,
0x39,0,19,0xB1,0x03,0xC8,0x04,0x1A,0x04,0x68,0x04,0xA5,0x04,0xE6,0x05,0x58,0x05,0xC0,0x06,0x1C,0x06,0x6B,
0x39,0,15,0xB2,0x07,0x07,0x07,0x93,0x08,0x10,0x08,0x46,0x08,0x61,0x08,0x79,0x08,0x79,
0x39,0,19,0xB3,0x00,0x00,0x01,0xCB,0x01,0xEE,0x02,0x11,0x02,0x27,0x02,0x63,0x02,0x9C,0x02,0xD2,0x03,0x06,
0x39,0,19,0xB4,0x03,0x62,0x03,0xB3,0x03,0xFC,0x04,0x3B,0x04,0x77,0x04,0xE0,0x05,0x40,0x05,0x93,0x05,0xE0,
0x39,0,15,0xB5,0x06,0x72,0x06,0xF6,0x07,0x68,0x07,0x97,0x07,0xAF,0x07,0xC6,0x07,0xC6,
0x39,0,19,0xB6,0x00,0x00,0x01,0xE8,0x02,0x1B,0x02,0x4E,0x02,0x79,0x02,0xDC,0x03,0x33,0x03,0x81,0x03,0xCA,
0x39,0,19,0xB7,0x04,0x48,0x04,0xAD,0x05,0x0C,0x05,0x58,0x05,0xA2,0x06,0x23,0x06,0x96,0x06,0xFF,0x07,0x5B,
0x39,0,15,0xB8,0x08,0x0C,0x08,0xAF,0x09,0x3E,0x09,0x7C,0x09,0x9B,0x09,0xBA,0x09,0xBA,
0x39,0,2,0xBF,0x37,
0x39,0,19,0xB0,0x00,0x00,0x01,0xE6,0x02,0x07,0x02,0x28,0x02,0x49,0x02,0x88,0x02,0xC4,0x02,0xF9,0x03,0x2D,
0x39,0,19,0xB1,0x03,0x7D,0x03,0xCC,0x04,0x13,0x04,0x4F,0x04,0x8B,0x04,0xF0,0x05,0x4F,0x05,0xA5,0x05,0xF2,
0x39,0,15,0xB2,0x06,0x7A,0x06,0xF9,0x07,0x6C,0x07,0xA4,0x07,0xBF,0x07,0xDA,0x07,0xDA,
0x39,0,19,0xB3,0x00,0x00,0x01,0xE3,0x01,0xF7,0x02,0x0B,0x02,0x18,0x02,0x44,0x02,0x75,0x02,0xA3,0x02,0xD1,
0x39,0,19,0xB4,0x03,0x1F,0x03,0x69,0x03,0xAD,0x03,0xE7,0x04,0x1E,0x04,0x7F,0x04,0xD7,0x05,0x25,0x05,0x6D,
0x39,0,15,0xB5,0x05,0xEE,0x06,0x63,0x06,0xD0,0x07,0x04,0x07,0x1E,0x07,0x37,0x07,0x37,
0x39,0,19,0xB6,0x00,0x00,0x01,0xFD,0x02,0x1F,0x02,0x41,0x02,0x5E,0x02,0xAA,0x02,0xF8,0x03,0x3E,0x03,0x80,
0x39,0,19,0xB7,0x03,0xEC,0x04,0x4E,0x04,0xA5,0x04,0xEF,0x05,0x34,0x05,0xAB,0x06,0x17,0x06,0x77,0x06,0xCF,
0x39,0,15,0xB8,0x07,0x6C,0x07,0xFB,0x08,0x7E,0x08,0xBF,0x08,0xDE,0x08,0xFD,0x08,0xFD,
0x39,0,2,0xBF,0x36,
0x39,0,19,0xB0,0x00,0x00,0x01,0xDA,0x01,0xF5,0x02,0x10,0x02,0x2B,0x02,0x54,0x02,0x7D,0x02,0xA8,0x02,0xD1,
0x39,0,19,0xB1,0x03,0x14,0x03,0x51,0x03,0x8C,0x03,0xBF,0x03,0xF1,0x04,0x46,0x04,0x9A,0x04,0xDE,0x05,0x21,
0x39,0,15,0xB2,0x05,0x94,0x05,0xFA,0x06,0x5C,0x06,0x8A,0x06,0x9F,0x06,0xB4,0x06,0xB4,
0x39,0,19,0xB3,0x00,0x00,0x01,0xD8,0x01,0xEB,0x01,0xFE,0x02,0x0A,0x02,0x20,0x02,0x3C,0x02,0x5E,0x02,0x7E,
0x39,0,19,0xB4,0x02,0xBC,0x02,0xF5,0x03,0x2D,0x03,0x5D,0x03,0x8C,0x03,0xDC,0x04,0x2B,0x04,0x6C,0x04,0xAC,
0x39,0,15,0xB5,0x05,0x1A,0x05,0x7C,0x05,0xD4,0x05,0xFE,0x06,0x11,0x06,0x24,0x06,0x24,
0x39,0,19,0xB6,0x00,0x00,0x01,0xE9,0x02,0x07,0x02,0x25,0x02,0x3E,0x02,0x6D,0x02,0x9D,0x02,0xD3,0x03,0x07,
0x39,0,19,0xB7,0x03,0x61,0x03,0xB0,0x03,0xFE,0x04,0x3E,0x04,0x7C,0x04,0xE2,0x05,0x46,0x05,0x95,0x05,0xE3,
0x39,0,15,0xB8,0x06,0x69,0x06,0xE0,0x07,0x4E,0x07,0x81,0x07,0x99,0x07,0xAF,0x07,0xAF,
0x39,0,2,0xBF,0x35,
0x39,0,19,0xB0,0x00,0x00,0x01,0xD3,0x01,0xE7,0x01,0xFB,0x02,0x0F,0x02,0x34,0x02,0x61,0x02,0x8D,0x02,0xB5,
0x39,0,19,0xB1,0x03,0x03,0x03,0x44,0x03,0x80,0x03,0xB9,0x03,0xE9,0x04,0x3E,0x04,0x91,0x04,0xD6,0x05,0x19,
0x39,0,15,0xB2,0x05,0x8E,0x05,0xF6,0x06,0x56,0x06,0x84,0x06,0x9B,0x06,0xB0,0x06,0xB0,
0x39,0,19,0xB3,0x00,0x00,0x01,0xD0,0x01,0xE3,0x01,0xF6,0x02,0x02,0x02,0x16,0x02,0x33,0x02,0x4E,0x02,0x6F,
0x39,0,19,0xB4,0x02,0xAE,0x02,0xEA,0x03,0x22,0x03,0x56,0x03,0x84,0x03,0xD6,0x04,0x26,0x04,0x67,0x04,0xA7,
0x39,0,15,0xB5,0x05,0x15,0x05,0x76,0x05,0xCE,0x05,0xF9,0x06,0x0D,0x06,0x20,0x06,0x20,
0x39,0,19,0xB6,0x00,0x00,0x01,0xE6,0x02,0x01,0x02,0x1C,0x02,0x33,0x02,0x5E,0x02,0x91,0x02,0xC3,0x02,0xF4,
0x39,0,19,0xB7,0x03,0x54,0x03,0xA9,0x03,0xF4,0x04,0x3A,0x04,0x75,0x04,0xDC,0x05,0x41,0x05,0x91,0x05,0xDF,
0x39,0,15,0xB8,0x06,0x65,0x06,0xDC,0x07,0x47,0x07,0x7B,0x07,0x95,0x07,0xAC,0x07,0xAC,
0x39,0,2,0xBF,0x34,
0x39,0,19,0xB0,0x00,0x00,0x02,0x30,0x02,0x3B,0x02,0x46,0x02,0x51,0x02,0x68,0x02,0x88,0x02,0xA7,0x02,0xCD,
0x39,0,19,0xB1,0x03,0x15,0x03,0x4E,0x03,0x85,0x03,0xB7,0x03,0xE8,0x04,0x3B,0x04,0x8D,0x04,0xD1,0x05,0x13,
0x39,0,15,0xB2,0x05,0x88,0x05,0xEE,0x06,0x4A,0x06,0x78,0x06,0x8E,0x06,0xA1,0x06,0xA1,
0x39,0,19,0xB3,0x00,0x00,0x02,0x1A,0x02,0x26,0x02,0x32,0x02,0x3E,0x02,0x4D,0x02,0x62,0x02,0x76,0x02,0x92,
0x39,0,19,0xB4,0x02,0xC8,0x02,0xFB,0x03,0x2D,0x03,0x5B,0x03,0x87,0x03,0xD6,0x04,0x24,0x04,0x63,0x04,0xA0,
0x39,0,15,0xB5,0x05,0x0F,0x05,0x6F,0x05,0xC3,0x05,0xEE,0x06,0x02,0x06,0x13,0x06,0x13,
0x39,0,19,0xB6,0x00,0x00,0x02,0x39,0x02,0x4C,0x02,0x5F,0x02,0x72,0x02,0x93,0x02,0xBA,0x02,0xE0,0x03,0x0E,
0x39,0,19,0xB7,0x03,0x67,0x03,0xB0,0x03,0xF8,0x04,0x36,0x04,0x72,0x04,0xD7,0x05,0x3A,0x05,0x89,0x05,0xD6,
0x39,0,15,0xB8,0x06,0x5C,0x06,0xD1,0x07,0x38,0x07,0x6C,0x07,0x85,0x07,0x9B,0x07,0x9B,
0x39,0,2,0xBF,0x33,
0x39,0,19,0xB0,0x00,0x00,0x02,0x77,0x02,0x81,0x02,0x8B,0x02,0x95,0x02,0xA9,0x02,0xBD,0x02,0xD6,0x02,0xED,
0x39,0,19,0xB1,0x03,0x25,0x03,0x5B,0x03,0x8F,0x03,0xBE,0x03,0xEB,0x04,0x39,0x04,0x86,0x04,0xC7,0x05,0x07,
0x39,0,15,0xB2,0x05,0x75,0x05,0xD7,0x06,0x34,0x06,0x60,0x06,0x75,0x06,0x8A,0x06,0x8A,
0x39,0,19,0xB3,0x00,0x00,0x02,0x63,0x02,0x6E,0x02,0x79,0x02,0x84,0x02,0x9A,0x02,0xA8,0x02,0xB9,0x02,0xC8,
0x39,0,19,0xB4,0x02,0xF0,0x03,0x1A,0x03,0x43,0x03,0x6D,0x03,0x95,0x03,0xDD,0x04,0x23,0x04,0x60,0x04,0x9C,
0x39,0,15,0xB5,0x05,0x01,0x05,0x5C,0x05,0xAF,0x05,0xD9,0x05,0xEC,0x05,0xFE,0x05,0xFE,
0x39,0,19,0xB6,0x00,0x00,0x02,0x8D,0x02,0x9C,0x02,0xAB,0x02,0xBA,0x02,0xD8,0x02,0xF1,0x03,0x11,0x03,0x30,
0x39,0,19,0xB7,0x03,0x79,0x03,0xBD,0x03,0xFF,0x04,0x3A,0x04,0x73,0x04,0xD2,0x05,0x30,0x05,0x7D,0x05,0xC9,
0x39,0,15,0xB8,0x06,0x48,0x06,0xB6,0x07,0x1F,0x07,0x52,0x07,0x6A,0x07,0x81,0x07,0x81,
0x39,0,2,0xBF,0x32,
0x39,0,19,0xB0,0x00,0x00,0x02,0xC9,0x02,0xCF,0x02,0xD5,0x02,0xDB,0x02,0xE8,0x02,0xF5,0x03,0x07,0x03,0x17,
0x39,0,19,0xB1,0x03,0x3D,0x03,0x68,0x03,0x92,0x03,0xBE,0x03,0xE8,0x04,0x30,0x04,0x76,0x04,0xB2,0x04,0xEC,
0x39,0,15,0xB2,0x05,0x57,0x05,0xB7,0x06,0x0C,0x06,0x36,0x06,0x4A,0x06,0x5B,0x06,0x5B,
0x39,0,19,0xB3,0x00,0x00,0x02,0xC0,0x02,0xC8,0x02,0xD0,0x02,0xD8,0x02,0xE9,0x02,0xF4,0x02,0xFF,0x03,0x09,
0x39,0,19,0xB4,0x03,0x23,0x03,0x43,0x03,0x61,0x03,0x84,0x03,0xA5,0x03,0xE3,0x04,0x20,0x04,0x56,0x04,0x8B,
0x39,0,15,0xB5,0x04,0xEB,0x05,0x41,0x05,0x8F,0x05,0xB6,0x05,0xC8,0x05,0xD7,0x05,0xD7,
0x39,0,19,0xB6,0x00,0x00,0x02,0xE4,0x02,0xF0,0x02,0xFC,0x03,0x08,0x03,0x20,0x03,0x34,0x03,0x4A,0x03,0x5F,
0x39,0,19,0xB7,0x03,0x93,0x03,0xCA,0x04,0x00,0x04,0x36,0x04,0x6A,0x04,0xC2,0x05,0x18,0x05,0x61,0x05,0xA8,
0x39,0,15,0xB8,0x06,0x22,0x06,0x91,0x06,0xF3,0x07,0x23,0x07,0x3A,0x07,0x4D,0x07,0x4D,
0x39,0,2,0xBF,0x31,
0x39,0,19,0xB0,0x00,0x00,0x03,0x29,0x03,0x2A,0x03,0x2B,0x03,0x2C,0x03,0x2F,0x03,0x32,0x03,0x35,0x03,0x43,
0x39,0,19,0xB1,0x03,0x61,0x03,0x7F,0x03,0x9C,0x03,0xBE,0x03,0xDF,0x04,0x1E,0x04,0x5C,0x04,0x93,0x04,0xC8,
0x39,0,15,0xB2,0x05,0x29,0x05,0x80,0x05,0xD2,0x05,0xFA,0x06,0x0C,0x06,0x1D,0x06,0x1D,
0x39,0,19,0xB3,0x00,0x00,0x03,0x39,0x03,0x39,0x03,0x39,0x03,0x39,0x03,0x3A,0x03,0x3B,0x03,0x3C,0x03,0x47,
0x39,0,19,0xB4,0x03,0x5D,0x03,0x72,0x03,0x85,0x03,0x9E,0x03,0xB5,0x03,0xE8,0x04,0x1A,0x04,0x49,0x04,0x77,
0x39,0,15,0xB5,0x04,0xCB,0x05,0x18,0x05,0x60,0x05,0x84,0x05,0x94,0x05,0xA3,0x05,0xA3,
0x39,0,19,0xB6,0x00,0x00,0x03,0x44,0x03,0x4B,0x03,0x52,0x03,0x59,0x03,0x67,0x03,0x75,0x03,0x81,0x03,0x92,
0x39,0,19,0xB7,0x03,0xB8,0x03,0xDE,0x04,0x03,0x04,0x2E,0x04,0x58,0x04,0xA7,0x04,0xF5,0x05,0x38,0x05,0x79,
0x39,0,15,0xB8,0x05,0xEC,0x06,0x51,0x06,0xB0,0x06,0xDC,0x06,0xF1,0x07,0x05,0x07,0x05,
0x39,0,2,0xBF,0x30,
0x39,0,19,0xB0,0x00,0x00,0x03,0x60,0x03,0x63,0x03,0x66,0x03,0x69,0x03,0x6F,0x03,0x75,0x03,0x7B,0x03,0x81,
0x39,0,19,0xB1,0x03,0x8D,0x03,0x9C,0x03,0xAE,0x03,0xC2,0x03,0xD6,0x04,0x01,0x04,0x2B,0x04,0x55,0x04,0x7D,
0x39,0,15,0xB2,0x04,0xC9,0x05,0x10,0x05,0x54,0x05,0x75,0x05,0x84,0x05,0x94,0x05,0x94,
0x39,0,19,0xB3,0x00,0x00,0x03,0x67,0x03,0x6B,0x03,0x6F,0x03,0x73,0x03,0x7B,0x03,0x83,0x03,0x8B,0x03,0x93,
0x39,0,19,0xB4,0x03,0x9E,0x03,0xAB,0x03,0xB7,0x03,0xC3,0x03,0xD1,0x03,0xEF,0x04,0x0D,0x04,0x2E,0x04,0x4D,
0x39,0,15,0xB5,0x04,0x8C,0x04,0xC7,0x05,0x00,0x05,0x1C,0x05,0x28,0x05,0x36,0x05,0x36,
0x39,0,19,0xB6,0x00,0x00,0x03,0x96,0x03,0x9B,0x03,0xA0,0x03,0xA5,0x03,0xAF,0x03,0xB9,0x03,0xC3,0x03,0xCD,
0x39,0,19,0xB7,0x03,0xDF,0x03,0xF5,0x04,0x0B,0x04,0x24,0x04,0x3E,0x04,0x77,0x04,0xAB,0x04,0xE0,0x05,0x14,
0x39,0,15,0xB8,0x05,0x76,0x05,0xCB,0x06,0x1C,0x06,0x42,0x06,0x54,0x06,0x66,0x06,0x66,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,2,0xBF,0x82,
0x39,0,19,0xB0,0x00,0x00,0x03,0x0E,0x03,0x32,0x03,0x56,0x03,0x7A,0x03,0xC2,0x03,0xEF,0x04,0x1B,0x04,0x48,
0x39,0,19,0xB1,0x04,0x9F,0x04,0xE0,0x05,0x20,0x05,0x5D,0x05,0x91,0x05,0xF6,0x06,0x41,0x06,0x8E,0x06,0xD9,
0x39,0,15,0xB2,0x07,0x11,0x07,0xA0,0x07,0xFF,0x08,0x2A,0x08,0x3F,0x08,0x52,0x08,0x52,
0x39,0,19,0xB3,0x00,0x00,0x02,0xE3,0x02,0xFF,0x03,0x1B,0x03,0x37,0x03,0x5B,0x03,0x92,0x03,0xC7,0x03,0xF3,
0x39,0,19,0xB4,0x04,0x47,0x04,0x81,0x04,0xB9,0x04,0xF4,0x05,0x24,0x05,0x82,0x05,0xC9,0x06,0x0D,0x06,0x4F,
0x39,0,15,0xB5,0x06,0x84,0x07,0x07,0x07,0x5C,0x07,0x83,0x07,0x98,0x07,0xAB,0x07,0xAB,
0x39,0,19,0xB6,0x00,0x00,0x02,0xD2,0x03,0x06,0x03,0x3A,0x03,0x6E,0x03,0xC6,0x04,0x0C,0x04,0x50,0x04,0x8C,
0x39,0,19,0xB7,0x05,0x00,0x05,0x4C,0x05,0x97,0x05,0xE0,0x06,0x1C,0x06,0x92,0x06,0xEC,0x07,0x3D,0x07,0x8C,
0x39,0,15,0xB8,0x07,0xD4,0x08,0x6F,0x08,0xD9,0x09,0x0A,0x09,0x22,0x09,0x39,0x09,0x39,
0x39,0,2,0xBF,0x81,
0x39,0,19,0xB0,0x00,0x00,0x02,0x54,0x03,0x25,0x03,0x41,0x03,0x5C,0x03,0x93,0x03,0xC7,0x03,0xE9,0x04,0x0B,
0x39,0,19,0xB1,0x04,0x4F,0x04,0x91,0x04,0xC6,0x04,0xF7,0x05,0x28,0x05,0x7F,0x05,0xCC,0x06,0x10,0x06,0x4A,
0x39,0,15,0xB2,0x06,0xBE,0x06,0xF9,0x07,0x42,0x07,0x78,0x07,0x94,0x07,0xAA,0x07,0xAC,
0x39,0,19,0xB3,0x00,0x00,0x02,0x33,0x02,0xF5,0x03,0x0A,0x03,0x20,0x03,0x43,0x03,0x61,0x03,0x8B,0x03,0xB3,
0x39,0,19,0xB4,0x03,0xFA,0x04,0x3A,0x04,0x6A,0x04,0x95,0x04,0xC0,0x05,0x13,0x05,0x5B,0x05,0x9B,0x05,0xD1,
0x39,0,15,0xB5,0x06,0x37,0x06,0x6E,0x06,0xB1,0x06,0xE3,0x06,0xFC,0x07,0x10,0x07,0x11,
0x39,0,19,0xB6,0x00,0x00,0x02,0x26,0x02,0xF3,0x03,0x1B,0x03,0x43,0x03,0x8C,0x03,0xCE,0x04,0x03,0x04,0x37,
0x39,0,19,0xB7,0x04,0x95,0x04,0xED,0x05,0x2E,0x05,0x67,0x05,0xA0,0x06,0x07,0x06,0x61,0x06,0xB1,0x06,0xF5,
0x39,0,15,0xB8,0x07,0x6F,0x07,0xB6,0x08,0x09,0x08,0x44,0x08,0x62,0x08,0x7A,0x08,0x7C,
0x39,0,2,0xBF,0x80,
0x39,0,19,0xB0,0x00,0x00,0x00,0xFD,0x02,0xF6,0x03,0x19,0x03,0x25,0x03,0x3C,0x03,0x53,0x03,0x6B,0x03,0x82,
0x39,0,19,0xB1,0x03,0xB0,0x03,0xD4,0x03,0xF1,0x04,0x0E,0x04,0x2A,0x04,0x64,0x04,0x9C,0x04,0xC7,0x04,0xF0,
0x39,0,15,0xB2,0x05,0x41,0x05,0x89,0x05,0xCA,0x05,0xEB,0x05,0xFA,0x06,0x06,0x06,0x07,
0x39,0,19,0xB3,0x00,0x00,0x00,0xEF,0x02,0xCD,0x02,0xEC,0x02,0xF5,0x03,0x07,0x03,0x19,0x03,0x2B,0x03,0x3B,
0x39,0,19,0xB4,0x03,0x52,0x03,0x71,0x03,0x95,0x03,0xB7,0x03,0xD6,0x04,0x0E,0x04,0x44,0x04,0x6A,0x04,0x8F,
0x39,0,15,0xB5,0x04,0xD9,0x05,0x1C,0x05,0x59,0x05,0x78,0x05,0x86,0x05,0x91,0x05,0x92,
0x39,0,19,0xB6,0x00,0x00,0x00,0xE9,0x02,0xBC,0x02,0xE2,0x02,0xF3,0x03,0x14,0x03,0x36,0x03,0x58,0x03,0x78,
0x39,0,19,0xB7,0x03,0xB0,0x03,0xE2,0x04,0x0F,0x04,0x3B,0x04,0x64,0x04,0xB1,0x04,0xFC,0x05,0x2E,0x05,0x5F,
0x39,0,15,0xB8,0x05,0xBF,0x06,0x12,0x06,0x5F,0x06,0x85,0x06,0x97,0x06,0xA5,0x06,0xA7,
0x39,0,2,0xCE,0x01,
0x39,0,2,0xCC,0x00,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x02,
0x39,0,25,0xB9,0x00,0x04,0x00,0x0C,0x00,0x14,0x00,0x1C,0x00,0x2C,0x00,0x3C,0x00,0x4C,0x00,0x5C,0x00,0x7C,0x00,0x9C,0x00,0xBC,0x00,0xDC,
0x39,0,25,0xBA,0x00,0xFC,0x01,0x3C,0x01,0x7C,0x01,0xBC,0x01,0xFC,0x02,0x7C,0x02,0xFC,0x03,0x7C,0x03,0xBC,0x03,0xDC,0x03,0xFC,0x03,0xFF,
#if TX_USE_CMD_MODE
0x39,0,2,0x17,0x10,
#else
0x39,0,2,0x17,0x01,
#endif
0x39,0,5,0x2A,0x00,0x00,0x04,0xC7,
0x39,0,5,0x2B,0x00,0x00,0x0A,0x8B,
0x39,0,2,0x2F,0x01,
0x39,0,2,0x35,0x00,
0x39,0,3,0x51,0x0D,0xBB,
0x39,0,2,0x6F,0x04,
0x39,0,3,0x51,0x0F,0xFF,
0x39,0,2,0x6F,0x07,
0x39,0,3,0x51,0x8F,0xFF,
0x39,0,2,0x6F,0x01,
0x39,0,3,0x87,0x0D,0xBB,
0x39,0,10,0x88,0x03,0x02,0x63,0x09,0x6A,0x00,0x00,0x00,0x00,
0x39,0,2,0x53,0x20,
0x39,0,3,0x90,0x00,0x00,
0x39,0,19,0x91,0xAB,0xA8,0x00,0x0C,0xD2,0x00,0x02,0x4C,0x01,0x24,0x00,0x08,0x09,0x75,0x07,0x7B,0x10,0xF0,
0x39,0,6,0xF0,0x55,0xAA,0x52,0x08,0x01,
0x39,0,2,0x6F,0x02,
0x39,0,3,0xC7,0x00,0x00,
0x39,0,2,0x26,0x00,
0x39,0,2,0x2F,0x01,
//0x39,0,1,0x11,
//0x39,0,1,0x29,
//	
#endif


};
#endif

/*****************************************************************************
*GPIO发送swire波形
*flag:  =0, SWIRE=0;  =1,仅发送SWIRE信号; =2, 先置高再发SWIRE信号
*num: 发几个脉冲
*注意FLAG=1时无GPIO初始化!!!!!!
*****************************************************************************/
void Gpio_swire_output(uint8_t flag, uint8_t num)
{
	uint8_t ii;

	if (flag)
	{
		if (flag ==2)
		{
			hal_gpio_init_output(IO_PAD_AP_SWIRE, IO_LVL_HIGH);	  
			delayMs(2);
		}
		for (ii =0; ii< num; ii++)
		{
			hal_gpio_set_output_data(IO_PAD_AP_SWIRE, IO_LVL_LOW);
			delayUs(10);
			hal_gpio_set_output_data(IO_PAD_AP_SWIRE, IO_LVL_HIGH);
			delayUs(9);
		}
	}
	else
	{
		hal_gpio_init_output(IO_PAD_AP_SWIRE, IO_LVL_LOW);	  
	}
}

/**
* @brief  panel init
* @param  none
* @retval none
*/
static void app_init_panel(void)
{
    /* reset panel*/
    app_tx_panel_reset();
    send_panel_init_code(sizeof(panel_init_code), (uint8_t *) panel_init_code);
	hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x11);
	delayMs(10);
	hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, 0x05, 0x0F);  //最大0FFF
	hal_gpio_init_output(IO_PAD_AP_PWMEN, IO_LVL_HIGH);		
	delayMs(60);  //90
#if AP_SWIRE_OUTPUT
    hal_swire_enable(true);
    hal_swire_set_pulse(SWIRE_DEFAULT_PULSE);
#endif
//	Gpio_swire_output(2, 40);   
//	delayMs(40);

}

#if TX_CMD_MODE_WITHOUT_TE
/**
* @brief  MIPI RX事件处理函数,demo code 用于command mode 输出发送数据（模式1）
* @param  event:RX事件
* @param  data: user data
* @retval none
*/
static void app_rx_event_cb(hal_rx_event_e event, void *data)
{
    if (panel_display_done && event == HAL_RX_LINE_EVENT)
    {
        hal_dsi_tx_ctrl_gen_a_frame();
    }
}
#endif

#if TX_USE_CMD_MODE
/**
* @brief  TE引脚作为GPIO 输入回调函数,demo code 用于command mode 输出发送数据（模式2）
* @param  none
* @retval none
*/
static void app_tx_cmd_panel_te_cb(void *data)
{
    if (panel_display_done)
    {
        //delayUs(25); /* 撕裂调试 */
        hal_dsi_tx_ctrl_gen_a_frame();
    }
}

/**
* @brief  注册屏端TE信号输入引脚回调函数
* @param  pad :TE输入pad
* @param  trig:触发中断沿配置
* @retval none
*/
static void app_tx_cmd_app_init_panel_te_int(io_pad_e pad, sys_cfg_trigger_e trig)
{
    /*1.关闭中断*/
    hal_gpio_ctrl_eint(pad, DISABLE);

    /*2.中断初始化*/
    hal_gpio_init_eint(pad, trig);

    /*3.注册回调*/
    hal_gpio_reg_eint_cb(pad, app_tx_cmd_panel_te_cb);

    /*4.使能中断*/
    hal_gpio_ctrl_eint(pad, ENABLE);
}
#endif

/**
* @brief  mipi rx 初始化
* @param  none
* @retval none
*/
static void app_mipi_rx_init(void)
{
    if (g_rx_ctrl_handle == NULL)
    {
        /* 创建rx   ctrl handle */
        g_rx_ctrl_handle = hal_dsi_rx_ctrl_create_handle();
    }
    /* 配置参数 */
    g_rx_ctrl_handle->base_info.src_w = INPUT_WIDTH;
    g_rx_ctrl_handle->base_info.src_h = INPUT_HEIGHT;
    g_rx_ctrl_handle->base_info.dst_w = OUTPUT_WIDTH;
    g_rx_ctrl_handle->base_info.dst_h = OUTPUT_HEIGHT;
    g_rx_ctrl_handle->base_info.src_frate = INPUT_FRAME_RATE;
    g_rx_ctrl_handle->base_info.src_mode = INPUT_DATA_MODE;
    g_rx_ctrl_handle->base_info.dst_mode = OUTPUT_DATA_MODE;
    g_rx_ctrl_handle->rx_color_mode = INPUT_COLOR_MODE;
    g_rx_ctrl_handle->rx_lanes = INPUT_MIPI_LANE_NUM;
    g_rx_ctrl_handle->rx_nonburst_models = INPUT_VIDEO_MODEL; /* 可不配置 */
    g_rx_ctrl_handle->compress_en = INPUT_COMPRESS;
    g_rx_ctrl_handle->rx_hsclk_rate = INPUT_MIPI_LANE_RATE;
    g_rx_ctrl_handle->cus_dcs_entry_table = g_cus_rx_dcs_execute_table; /* 注册 DCS处理列表 */
    g_rx_ctrl_handle->rx_dcs_read_entry = ap_dcs_read; /* 注册dsc read 回调函数,可选,此函数为空时由cus_dcs_entry_table执行 */
		
		g_rx_ctrl_handle->extra_info.flow_control_mode = FC_C2V_NORMAL_MODE;
		
		g_rx_ctrl_handle->rx_lane_swap = RX_LANE_SWAP_3012;
		g_rx_ctrl_handle->base_info.pn_swap =  RX_LANE_0_PN_SWAP|RX_LANE_1_PN_SWAP|RX_LANE_2_PN_SWAP|RX_LANE_3_PN_SWAP|RX_LANE_CLK_PN_SWAP;
	//	g_rx_ctrl_handle->rx_strength=7;
//		g_rx_ctrl_handle->hight_performan_mode = HIGHT_PERFORMAN_L2;
//		g_rx_ctrl_handle->err_handler_level = ERR_HANDLE_L2;
	
		hal_dsi_rx_ctrl_set_check_crc(g_rx_ctrl_handle, false);
		
#if RX_RESOLUTION_CHANGE_ENABLE
    g_rx_ctrl_handle->pps_update_entry = pps_update_handle;
#endif
    /* 提前预置PPS,  AP 有PPS cmd也会更新 */
    if (g_rx_ctrl_handle->compress_en == true)
    {
        uint8_t pps[128] = {
					  0x12,0x00,0x00,0xAB,0x30,0x80,0x0A,0x8C,
						0x04,0xC8,0x00,0x14,0x02,0x64,0x02,0x64,
						0x02,0x00,0x02,0x4C,0x00,0x20,0x01,0xF1,
						0x00,0x08,0x00,0x0D,0x05,0x7A,0x04,0x7D,
						0x18,0x00,0x10,0xF0,0x07,0x10,0x20,0x00,
						0x06,0x0F,0x0F,0x33,0x0E,0x1C,0x2A,0x38,
						0x46,0x54,0x62,0x69,0x70,0x77,0x79,0x7B,
						0x7D,0x7E,0x02,0x02,0x22,0x00,0x2A,0x40,
						0x2A,0xBE,0x3A,0xFC,0x3A,0xFA,0x3A,0xF8,
						0x3B,0x38,0x3B,0x78,0x3B,0xB6,0x4B,0xB6,
						0x4B,0xF4,0x4B,0xF4,0x6C,0x34,0x84,0x74,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
                           };
        hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, pps, 128);
    }
		
//		g_rx_ctrl_handle->extra_info.blank_info.top = 20;
//		g_rx_ctrl_handle->extra_info.blank_info.enable = true;

    /* 初始化rx ctrl */
    hal_dsi_rx_ctrl_init(g_rx_ctrl_handle);
//		hal_dsi_rx_ctrl_set_log_level(kLOG_LEVEL_NONE);

#if RX_READ_HW_ACK
    /* 配置硬件回复 */
    app_set_dcs_hw_ack();
#endif

#if TX_CMD_MODE_WITHOUT_TE
    /* 注册接收一帧帧头事件回调,每接收一帧数据TX再往外发一帧 */
    //hal_dsi_rx_ctrl_register_callback(g_rx_ctrl_handle, app_rx_event_cb, HAL_RX_FS_EVENT, true, NULL);
    /* 注册接收第0行数据事件,接收到数据后再往外发送数据,确保不撕裂 */
    uint32_t line = 0;
    hal_dsi_rx_ctrl_register_callback(g_rx_ctrl_handle, app_rx_event_cb, HAL_RX_LINE_EVENT, true, &line);
#endif

#if RX_START_WITHOUT_RST
    /* 等待ap reset置位再启动rx,否则容易收到错误数据 */
    hal_dsi_rx_ctrl_start(g_rx_ctrl_handle);
#else
    /* 注册RX start callback,确认RX LP11时再启动RX,防止接收错误数据 */
    hal_gpio_set_ap_reset_int(ENABLE, app_mipi_rx_start_cb, DETECT_HIGH_LVL);
#endif
}

/**
* @brief  mipi tx 初始化
* @param  none
* @retval none
*/
static void app_mipi_tx_init(void)
{
    if (g_tx_ctrl_handle == NULL)
    {
        g_tx_ctrl_handle = hal_dsi_tx_ctrl_create_handle();
    }
    g_tx_ctrl_handle->channel_id = OUTPUT_VC;
    g_tx_ctrl_handle->lane_num = OUTPUT_LANE_NUMBER;
    g_tx_ctrl_handle->vid_mode = OUTPUT_VIDEO_MODEL;
    g_tx_ctrl_handle->cmd_tx_type = TX_INIT_TYPE;
    g_tx_ctrl_handle->dpi_vsa = OUTPUT_VSA;
    g_tx_ctrl_handle->dpi_vbp = OUTPUT_VBP;
    g_tx_ctrl_handle->dpi_vfp = OUTPUT_VFP;
    g_tx_ctrl_handle->dpi_hsa = OUTPUT_HSA;
    g_tx_ctrl_handle->dpi_hbp = OUTPUT_HBP;
    g_tx_ctrl_handle->dpi_hfp = OUTPUT_HFP;
    g_tx_ctrl_handle->base_info.src_w = INPUT_WIDTH;
    g_tx_ctrl_handle->base_info.src_h = INPUT_HEIGHT;
    g_tx_ctrl_handle->base_info.dst_w = OUTPUT_WIDTH;
    g_tx_ctrl_handle->base_info.dst_h = OUTPUT_HEIGHT;
    g_tx_ctrl_handle->base_info.src_frate = INPUT_FRAME_RATE;
    g_tx_ctrl_handle->base_info.src_mode = INPUT_DATA_MODE;
    g_tx_ctrl_handle->base_info.dst_mode = OUTPUT_DATA_MODE;
//		g_tx_ctrl_handle->tx_frame_rate = 62;
    /* 初始化屏时每一条LP CMD都退出LPDT 再进入发送下一条 */
    /* 解决FT8720 TDDI 显示翻转问题 */
//    g_tx_ctrl_handle->tx_lane_lp     = ALWAYS_HS;

    hal_dsi_tx_ctrl_init(g_tx_ctrl_handle);

    /* FIXME set tear on*/
 //   hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);

    /* AP 没有发送数据时默认的显示颜色, 量产为0 0 0(黑色), 配置其他颜色仅为debug使用 */
    hal_dsi_tx_ctrl_set_overwrite_rgb(0x00, 0x00, 0x00);
}

#if !RX_START_WITHOUT_RST
/**
* @brief  mipi rx start函数,开启AP RSTN等待启动配置后使用
* @param  none
* @retval none
*/
static void app_mipi_rx_start_cb(void *data)
{
    /* RX start */
    hal_dsi_rx_ctrl_start(g_rx_ctrl_handle);
    /* close cb */
    hal_gpio_set_ap_reset_int(DISABLE, NULL, DETECT_HIGH_LVL);
    TAU_LOGD("rx start\n");
}
#endif

/**
* @brief  mipi tx 启动
* @param  none
* @retval none
*/
static void app_mipi_tx_start(void)
{
    /* Init panel */
    app_init_panel();
    /* TX start */
    hal_dsi_tx_ctrl_start(g_tx_ctrl_handle);
    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
	
    panel_display_done = true;

    delayMs(120);
    /* Display on */
    hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x29);
	
#if (TX_USE_CMD_MODE & (!TX_CMD_MODE_WITHOUT_TE))                       /* cmd mode输出,并且需要屏的TE输入 */
    // hal_dsi_tx_ctrl_gen_a_frame(); /* FIXME */
    app_tx_cmd_app_init_panel_te_int(IO_PIN_14, DETECT_RISING_EDGE); /* 注册屏端TE中断 */
#endif
#if AP_SWIRE_OUTPUT
    hal_swire_set_pulse(SWIRE_DEFAULT_PULSE);
#endif
    TAU_LOGD("tx_start \n");
}

/**
* @brief  ap rstn 拉高中断回调,用于息屏唤醒
* @param  none
* @retval none
*/
static void ap_rstn_pull_high_cb(void *data)
{
    /* system resume begin */
    sg_system_resume = true;
    /* 关闭AP reset检查     */
    hal_gpio_set_ap_reset_int(DISABLE, NULL, DETECT_HIGH_LVL);
}

/**
* @brief  ap rstn 拉高中断回调,用于息屏待机
* @param  none
* @retval none
*/
static void ap_rstn_pull_down_cb(void *data)
{
    sg_system_suspend = true;
    /* 关闭AP reset检查     */
    hal_gpio_set_ap_reset_int(DISABLE, NULL, DETECT_HIGH_LVL);
    TAU_LOGD("ap_rstn_pull_down_cb\n");
}

/**
* @brief  GPIO初始化配置,根据实际原理图提前配置IO功能以及状态,默认功能可不配置
*         TP相关I2C/SPI 在tp_transfer.c,也可以挪到此函数初始化
* @param  none
* @retval none
*/
void app_gpio_init(void)
{
    io_pad_attr_t attrs[] =
    {
        {IO_PIN_8,  PIN8_MODE_GPIO7,     IO_IOE_OUTPUT, IO_LVL_LOW},/* PIN_8(TD_RSTN), GPIO,输出,低电平 */
        {IO_PIN_17, PIN17_MODE_GPIO8,   IO_IOE_OUTPUT, IO_LVL_LOW}, /* PIN_17(PWMEN), GPIO,输出,低电平 */
        {IO_PIN_16, PIN16_MODE_GPIO2,   IO_IOE_OUTPUT, IO_LVL_LOW}, /* PIN_16(AP_INT),GPIO,输出,低电平 */
#if (TX_USE_CMD_MODE & (!TX_CMD_MODE_WITHOUT_TE))
       {IO_PIN_14, PIN14_MODE_GPIO24,   IO_IOE_INPUT, IO_LVL_NONE}, /* PIN_29(AP_TE), cmd mode输出, 并且看屏TE,配置AP TE为GPIO输入 */
#endif
        {IO_PIN_29, PIN29_MODE_TEAR,    IO_IOE_NONE, IO_LVL_NONE},  /* PIN_29(AP_TE), 硬件TEAR输出模式 */

    };
    uint8_t size = sizeof(attrs) / sizeof(io_pad_attr_t);
    hal_gpio_config_pad(attrs, size);
}

/**
* @brief  显示相关模块初始化,包括MIPI RX/TX/PWM/SWIRE/GPIO等
* @param  none
* @retval none
*/
void app_display_init(void)
{
    /* mipi rx初始化 */
    app_mipi_rx_init();

    /* VCC 主供电,等待VCC Power Ready,此时RX初始化完成可以响应MIPI命令 */
    if (MAIN_POWER_SELECT == PWR_SEL_VCC)
    {
        while (hal_pwr_get_vcc_power_ready() == false);
    }

    /* GPIO 初始化   */
    app_gpio_init();
    /* 背光初始化      */
#if AP_SWIRE_OUTPUT
    hal_swire_init();   /*  swire init */
    hal_swire_set_timer(TIMER_NUM0, 8, true); /* swire连续发送,绑定timer进行发送 */
#endif
    /* mipi tx 初始化*/
    app_mipi_tx_init();
    app_mipi_tx_start();
}

/**
* @brief  系统resume
* @param  sleep_mode: sleep 模式
* @retval none
*/
static void app_system_resume(pwr_sleep_mode_e sleep_mode)
{
    /* 退出sleep mode, 电源切换 */
    hal_pwr_exit_sleep_mode();

    /* display resume */
    app_display_init();

#if TOUCH_ENABLE
    /* touch resume */
    app_tp_write_other_operations(NULL, 0);
#endif
    TAU_LOGD("system resume\n");
}

/**
* @brief  系统suspend,进入sleep mode
* @param  sleep_mode: sleep 模式
* @retval none
*/
static void app_system_suspend(pwr_sleep_mode_e sleep_mode)
{
    /* 关闭图像通路 */
    hal_dsi_tx_ctrl_stop(g_tx_ctrl_handle);
    hal_dsi_tx_ctrl_deinit(g_tx_ctrl_handle);
    hal_dsi_rx_ctrl_stop(g_rx_ctrl_handle);
    hal_dsi_rx_ctrl_deinit(g_rx_ctrl_handle);

    /* Tear拉低 */
    hal_gpio_init_output(IO_PAD_AP_TE, IO_LVL_LOW);
    panel_display_done = false;
#if RX_WAIT_TEAR_ON
    sg_ap_set_tear_on = false;
#endif

    /* 关闭外设 比如Swire/I2C/Flash 等 */
#if AP_SWIRE_OUTPUT
    hal_swire_deinit();
#endif
#if ANALOG_PWM_OUTPUT
    hal_pwm_deinit();
#endif

#if SHARE_FLASH_ENABLE
    hal_flash_share_mode(false);
#endif

    /* 切换TP18 供电 */
    hal_pwr_set_sleep_mode_power(SLEEP_MODE_POWER);

    if (sleep_mode == PWR_NORMAL_SLEEP_MODE)
    {
        /* normal sleep mode, MCU可以正常工作 */
        hal_gpio_set_ap_reset_int(ENABLE, ap_rstn_pull_high_cb, DETECT_HIGH_LVL);
        hal_pwr_enter_normal_sleep_mode();
    }
    else if (sleep_mode == PWR_STOP_SLEEP_MODE)
    {
        /* 注册对应 wakeup IO */
        hal_pwr_set_stop_sleep_wakeup_pin(IO_PAD_AP_RSTN, WUP_RISING_EDGE);
        //hal_pwr_set_stop_sleep_wakeup_pin(IO_PAD_AP_SPIS_CSN, WUP_FALLING_EDGE);
        //hal_pwr_set_stop_sleep_wakeup_pin(IO_PAD_TD_INT, WUP_FALLING_EDGE);
        io_pad_e wakeup_io = hal_pwr_enter_stop_sleep_mode();
        if (wakeup_io == IO_PAD_AP_RSTN)
        {
            sg_system_resume = true;
        }
        else
        {
            /* Not impletmented */
            TAU_LOGD("wakeup_io %d FIXME touch wakeup convert to AP\n", wakeup_io);
            hal_gpio_set_ap_reset_int(ENABLE, ap_rstn_pull_high_cb, DETECT_HIGH_LVL);
        }
    }
    else
    {
        /* deep sleep mode,配置AP RSTN 上升沿,TD INT 下降沿唤醒 */
        hal_pwr_enter_deep_sleep_mode(WUP_RISING_EDGE, WUP_FALLING_EDGE);
    }

}

/**
* @brief  系统process处理函数,处理待机唤醒等
* @param  none
* @retval none
*/
static void app_system_process(void)
{
    if (sg_system_suspend)
    {
        /* 系统进入sleep mode */
        app_system_suspend(SLEEP_MODE_SELECT);
        sg_system_suspend = false;
    }

    if (sg_system_resume)
    {
        /* 系统退出sleep mode */
        app_system_resume(SLEEP_MODE_SELECT);
        sg_system_resume = false;
    }

#if TX_START_AFTER_APRST
    if (sg_tx_start_in_process)
    {
        app_mipi_tx_start();
        sg_tx_start_in_process = false;
    }
#endif
}

static void CallingDisplayOffHandle( void )
{
    static unsigned char Flag = 0;       // 状态标志，防止反复执行函数状态
    static unsigned int  ExitDelay = 0;
    
    if(( 0 ==  Flag )&&(panel_display_done == true))
    {
        /* 引脚初始化 */ 
        hal_gpio_set_pull_state( TOUCH_PHONE_DIS_OFF_PIN, DISABLE, ENABLE ); // 设定初始上拉状态
        hal_gpio_init_input( TOUCH_PHONE_DIS_OFF_PIN );
			  
        Flag = 0xF0; // 更新标志，防止反复执行, 并进入到下个状态
    }
	else if(Flag == 0xF0)
	{
			if(phone_start_flag == 1) // 开机,需要等待6秒后触摸TP3V3电源稳定后再检测息屏IO状态
			{
				ExitDelay = hal_system_get_tick(); // 更新计时时间				
				phone_start_flag = 2;		// 更新标志，防止反复执行, 并进入到下个状态
			}
			else if(phone_start_flag == 2)
			{
				if( hal_system_get_tick() - ExitDelay > 10000 ) // 延时 10S 进入息屏IO检测状态
				{
						Flag = 1; // 更新标志，防止反复执行
						phone_start_flag = 0;
				}
			}
			else
			{
				Flag = 1; // 更新标志，并进入到下个状态
			}		
	}
     else if( ( IO_LVL_HIGH == hal_gpio_get_input_data( TOUCH_PHONE_DIS_OFF_PIN ) ) && ( 1 == Flag ) )
    {
        /* 高电平，刷黑操作 */
        hal_dsi_tx_ctrl_write_cmd( 0x05, 0, 1, 0x22 );
        Flag = 2; // 更新标志，防止反复执行    
		TAU_LOGD("all pixel off\n");
    }
    else if( ( IO_LVL_LOW == hal_gpio_get_input_data( TOUCH_PHONE_DIS_OFF_PIN ) ) && ( 2 == Flag ) )
    {
        /* 低电平, 退出操作 */
        ExitDelay = hal_system_get_tick(); // 更新计时时间
        //hal_dsi_tx_ctrl_write_cmd( 0x05, 0, 1, 0x13 );
        //Flag = 1; // 更新标志，防止反复执行
		TAU_LOGD("calling IO down\n");
        Flag = 3;
    }
    else if( 3 == Flag )
    {	
			
        if( hal_system_get_tick() - ExitDelay > 1000 ) // 延时 1S 退出黑屏状态
        {
            hal_dsi_tx_ctrl_write_cmd( 0x05, 0, 1, 0x13 );
            Flag = 1; // 更新标志，防止反复执行
						TAU_LOGD("all pixel on");
        }
        else if( IO_LVL_HIGH == hal_gpio_get_input_data( TOUCH_PHONE_DIS_OFF_PIN ) ) // 倒计时阶段又挡住了屏幕，继续更新时间
        {
            ExitDelay = hal_system_get_tick(); // 更新计时时间
			TAU_LOGD("TOUCH DOWN AGAIN\n");
        }else{
					hal_dsi_tx_ctrl_write_cmd( 0x05, 0, 1, 0x13 );
		TAU_LOGD("Nothing\n");
		}
		
    }
//	TAU_LOGD("PHONE CALIING STATE [%d]\n",hal_gpio_get_input_data( TOUCH_PHONE_DIS_OFF_PIN ));

}

/**
* @brief  mi12 lite demo 主函数
* @param  none
* @retval none
*/
void Note11Pro_demo(void)
{
    /* 电源选择,上电只需要选择一次 */
    hal_pwr_set_main_power(MAIN_POWER_SELECT);        /* 切换供电*/

    /* 显示模块初始 */
    app_display_init();
	
		hal_pwr_ldo18s_en(true);
		hal_pwr_ldo18s_set(LDO_18S_5);
//	
//		hal_pwr_ldo13s_en(true);
//		hal_pwr_ldo13s_set(LDO_13S_6);

    /* touch 相关模块初始化 */
#if TOUCH_ENABLE
    /* TP 初始化 */
    app_tp_init();
    app_tp_phone_clear_reset_on();
    /* 与屏的TP 模块通讯并初始化 */
    app_tp_transfer_screen_start();
#endif
	
#if AOD_CLOCK_ENABLE
    aod_init(g_rx_ctrl_handle, TIMER_NUM1, 95, 150, 180, &AOD_LowPower_Update, app_rx_event_cb);
		//TAU_LOGD("aod_init\n");
#endif
    //TAU_LOGD("s20p demo init done \n");

    while (1)
    {
        /* DCS 命令异步处理 */
        while (hal_dsi_rx_ctrl_dcs_async_handler(g_rx_ctrl_handle));

			
	//		CallingDisplayOffHandle();

        /* 系统事件处理(sleep mode) */
        app_system_process();
    }
}
#endif
